from .. import Provider as AddressProvider


class Provider(AddressProvider):
    address_formats = ["{{street_address}}, {{city_name}}, {{postcode}}"]
    building_number_formats = ["#", "##", "###"]
    city_formats = ["{{city_prefix}} {{city_name}}"]
    street_address_formats = (
        "{{street_prefix}} {{street_name}}, буд. {{building_number}}",
        "{{street_prefix}} {{street_name}}, буд. {{building_number}} кв. {{building_number}}",
    )

    street_name_formats = "{{street_prefix}} {{street_title}}"

    city_prefixes = ["місто", "село", "селище", "хутір"]

    city_names = (
        "Авдіївка",
        "Алмазна",
        "Алупка",
        "Алушта",
        "Алчевськ",
        "Амвросіївка",
        "Ананьїв",
        "Андрушівка",
        "Антрацит",
        "Апостолове",
        "Армянськ",
        "Арциз",
        "Балаклія",
        "Балта",
        "Бар",
        "Баранівка",
        "Барвінкове",
        "Батурин",
        "Бахмач",
        "Бахмут",
        "Бахчисарай",
        "Баштанка",
        "Белз",
        "Бердичів",
        "Бердянськ",
        "Берегове",
        "Бережани",
        "Березань",
        "Березівка",
        "Березне",
        "Берестечко",
        "Берислав",
        "Бершадь",
        "Бібрка",
        "Біла Церква",
        "Білгород-Дністровський",
        "Білицьке",
        "Білогірськ",
        "Білозерське",
        "Білопілля",
        "Біляївка",
        "Благовіщенське",
        "Бобринець",
        "Бобровиця",
        "Богодухів",
        "Богуслав",
        "Боково-Хрустальне",
        "Болград",
        "Болехів",
        "Борзна",
        "Борислав",
        "Бориспіль",
        "Борщів",
        "Боярка",
        "Бровари",
        "Броди",
        "Брянка",
        "Бунге",
        "Буринь",
        "Бурштин",
        "Буськ",
        "Буча",
        "Бучач",
        "Валки",
        "Вараш",
        "Василівка",
        "Васильків",
        "Багачеве",
        "Вашківці",
        "Великі Мости",
        "Верхівцеве",
        "Верхньодніпровськ",
        "Вижниця",
        "Вилкове",
        "Винники",
        "Виноградів",
        "Вишгород",
        "Вишневе",
        "Вільногірськ",
        "Вільнянськ",
        "Вінниця",
        "Вовчанськ",
        "Вознесенівка",
        "Вознесенськ",
        "Волноваха",
        "Володимир-Волинський",
        "Волочиськ",
        "Ворожба",
        "Вуглегірськ",
        "Вугледар",
        "Гадяч",
        "Гайворон",
        "Гайсин",
        "Галич",
        "Генічеськ",
        "Герца",
        "Гірник",
        "Гірське",
        "Глиняни",
        "Глобине",
        "Глухів",
        "Гнівань",
        "Гола Пристань",
        "Голубівка",
        "Горішні Плавні",
        "Горлівка",
        "Городенка",
        "Городище",
        "Городня",
        "Городок",
        "Горохів",
        "Гребінка",
        "Гуляйполе",
        "Дебальцеве",
        "Деражня",
        "Дергачі",
        "Джанкой",
        "Дніпро",
        "Дніпрорудне",
        "Добромиль",
        "Добропілля",
        "Довжанськ",
        "Докучаєвськ",
        "Долина",
        "Долинська",
        "Донецьк",
        "Дрогобич",
        "Хутір-Михайлівський",
        "Дружківка",
        "Дубляни",
        "Дубно",
        "Дубровиця",
        "Дунаївці",
        "Енергодар",
        "Євпаторія",
        "Єнакієве",
        "Жашків",
        "Жданівка",
        "Жидачів",
        "Житомир",
        "Жмеринка",
        "Жовква",
        "Жовті Води",
        "Заводське",
        "Залізне",
        "Заліщики",
        "Запоріжжя",
        "Заставна",
        "Збараж",
        "Зборів",
        "Звенигородка",
        "Здолбунів",
        "Зеленодольськ",
        "Зимогір'я",
        "Зіньків",
        "Зміїв",
        "Знам'янка",
        "Золоте",
        "Золотоноша",
        "Золочів",
        "Зоринськ",
        "Зугрес",
        "Івано-Франківськ",
        "Ізмаїл",
        "Ізюм",
        "Ізяслав",
        "Іллінці",
        "Іловайськ",
        "Інкерман",
        "Ірміно",
        "Ірпінь",
        "Іршава",
        "Ічня",
        "Кагарлик",
        "Кадіївка",
        "Калинівка",
        "Калуш",
        "Кальміуське",
        "Кам'янець-Подільський",
        "Кам'янка (Черкаська область)",
        "Кам'янка-Бузька",
        "Кам'янка-Дніпровська",
        "Кам'янське",
        "Камінь-Каширський",
        "Канів",
        "Карлівка",
        "Каховка",
        "Керч",
        "Київ",
        "Кипуче",
        "Ківерці",
        "Кілія",
        "Кіцмань",
        "Кобеляки",
        "Ковель",
        "Кодима",
        "Козятин",
        "Коломия",
        "Комарно",
        "Конотоп",
        "Копичинці",
        "Корець",
        "Коростень",
        "Коростишів",
        "Корсунь-Шевченківський",
        "Корюківка",
        "Косів",
        "Костопіль",
        "Костянтинівка",
        "Краматорськ",
        "Красилів",
        "Красногорівка",
        "Берестин",
        "Красноперекопськ",
        "Кременець",
        "Кременчук",
        "Кремінна",
        "Кривий Ріг",
        "Кролевець",
        "Кропивницький",
        "Куп'янськ",
        "Курахове",
        "Ладижин",
        "Ланівці",
        "Лебедин",
        "Лиман",
        "Липовець",
        "Лисичанськ",
        "Лозова",
        "Лохвиця",
        "Лубни",
        "Луганськ",
        "Лутугине",
        "Луцьк",
        "Львів",
        "Любомль",
        "Люботин",
        "Макіївка",
        "Мала Виска",
        "Малин",
        "Мар'їнка",
        "Марганець",
        "Маріуполь",
        "Мелітополь",
        "Мена",
        "Мерефа",
        "Миколаїв",
        "Миколаївка",
        "Миргород",
        "Мирноград",
        "Миронівка",
        "Міусинськ",
        "Могилів-Подільський",
        "Отаманівка",
        "Молочанськ",
        "Монастириська",
        "Монастирище",
        "Моршин",
        "Моспине",
        "Мостиська",
        "Мукачево",
        "Надвірна",
        "Немирів",
        "Нетішин",
        "Ніжин",
        "Нікополь",
        "Нова Каховка",
        "Нова Одеса",
        "Новгород-Сіверський",
        "Нове Давидково",
        "Новий Буг",
        "Новий Калинів",
        "Новий Розділ",
        "Новоазовськ",
        "Нововолинськ",
        "Новоград-Волинський",
        "Новогродівка",
        "Новодністровськ",
        "Новодружеськ",
        "Новомиргород",
        "Самар",
        "Новоселиця",
        "Новоукраїнка",
        "Новояворівськ",
        "Носівка",
        "Обухів",
        "Овруч",
        "Одеса",
        "Олевськ",
        "Олександрівськ",
        "Олександрія",
        "Олешки",
        "Оріхів",
        "Остер",
        "Острог",
        "Охтирка",
        "Очаків",
        "П'ятихатки",
        "Павлоград",
        "Сокологірськ",
        "Златопіль",
        "Перевальськ",
        "Перемишляни",
        "Перечин",
        "Перещепине",
        "Переяслав",
        "Шахтарське",
        "Петрово-Красносілля",
        "Пирятин",
        "Південне",
        "Підгайці",
        "Підгородне",
        "Погребище",
        "Подільськ",
        "Покров",
        "Покровськ",
        "Пологи",
        "Полонне",
        "Полтава",
        "Помічна",
        "Попасна",
        "Почаїв",
        "Привілля",
        "Прилуки",
        "Приморськ",
        "Прип'ять",
        "Пустомити",
        "Путивль",
        "Рава-Руська",
        "Радехів",
        "Радивилів",
        "Радомишль",
        "Рахів",
        "Рені",
        "Решетилівка",
        "Ржищів",
        "Рівне",
        "Ровеньки",
        "Рогатин",
        "Родинське",
        "Рожище",
        "Роздільна",
        "Ромни",
        "Рубіжне",
        "Рудки",
        "Саки",
        "Самбір",
        "Сарни",
        "Свалява",
        "Сватове",
        "Світловодськ",
        "Світлодарськ",
        "Святогірськ",
        "Севастополь",
        "Селидове",
        "Семенівка",
        "Середина-Буда",
        "Сіверськодонецьк",
        "Синельникове",
        "Сіверськ",
        "Сімферополь",
        "Скадовськ",
        "Скалат",
        "Сквира",
        "Сколе",
        "Славута",
        "Славутич",
        "Слов'янськ",
        "Сміла",
        "Снігурівка",
        "Сніжне",
        "Сновськ",
        "Снятин",
        "Сокаль",
        "Сокиряни",
        "Соледар",
        "Сорокине",
        "Соснівка",
        "Старий Крим",
        "Старий Самбір",
        "Старобільськ",
        "Старокостянтинів",
        "Стебник",
        "Сторожинець",
        "Стрий",
        "Судак",
        "Судова Вишня",
        "Суми",
        "Суходільськ",
        "Таврійськ",
        "Тальне",
        "Тараща",
        "Татарбунари",
        "Теплодар",
        "Теребовля",
        "Тернівка",
        "Тернопіль",
        "Тетіїв",
        "Тиврів",
        "Тисмениця",
        "Тлумач",
        "Токмак",
        "Торецьк",
        "Тростянець",
        "Трускавець",
        "Тульчин",
        "Турка",
        "Тячів",
        "Угнів",
        "Ужгород",
        "Узин",
        "Українка",
        "Українськ",
        "Умань",
        "Устилуг",
        "Фастів",
        "Федорівка",
        "Феодосія",
        "Харків",
        "Харцизьк",
        "Херсон",
        "Хирів",
        "Хмельницький",
        "Хмільник",
        "Ходорів",
        "Хорол",
        "Хоростків",
        "Хотин",
        "Хрестівка",
        "Христинівка",
        "Хрустальний",
        "Хуст",
        "Часів Яр",
        "Шептицький",
        "Черкаси",
        "Чернівці",
        "Чернігів",
        "Чигирин",
        "Чистякове",
        "Чоп",
        "Чорнобиль",
        "Чорноморськ",
        "Чортків",
        "Чугуїв",
        "Чуднів",
        "Шаргород",
        "Шахтарськ",
        "Шепетівка",
        "Шостка",
        "Шпола",
        "Шумськ",
        "Щастя",
        "Щолкіне",
        "Южне",
        "Южноукраїнськ",
        "Яворів",
        "Яготин",
        "Ялта",
        "Ямпіль",
        "Яремче",
        "Ясинувата",
    )

    region_names = (
        "Автономна Республіка Крим",
        "Вінницька область",
        "Волинська область",
        "Дніпропетровська область",
        "Донецька область",
        "Житомирська область",
        "Закарпатська область",
        "Запорізька область",
        "Івано-Франківська область",
        "Київська область",
        "Кіровоградська область",
        "Луганська область",
        "Львівська область",
        "Миколаївська область",
        "Одеська область",
        "Полтавська область",
        "Рівненська область",
        "Сумська область",
        "Тернопільська область",
        "Харківська область",
        "Херсонська область",
        "Хмельницька область",
        "Черкаська область",
        "Чернівецька область",
        "Чернігівська область",
    )

    countries = [
        "Австралія",
        "Австрія",
        "Азербайджан",
        "Албанія",
        "Алжир",
        "Ангола",
        "Андорра",
        "Антигуа і Барбуда",
        "Аргентина",
        "Афганістан",
        "Багамські Острови",
        "Бангладеш",
        "Барбадос",
        "Бахрейн",
        "Беліз",
        "Бельгія",
        "Бенін",
        "Білорусь",
        "Болгарія",
        "Болівія",
        "Боснія і Герцеговина",
        "Ботсвана",
        "Бразилія",
        "Бруней",
        "Буркіна-Фасо",
        "Бурунді",
        "Бутан",
        "Вануату",
        "Ватикан",
        "Велика Британія",
        "Венесуела",
        "В'єтнам",
        "Вірменія",
        "Габон",
        "Гаїті",
        "Гаяна",
        "Гамбія",
        "Гана",
        "Гватемала",
        "Гвінея",
        "Гвінея-Бісау",
        "Гондурас",
        "Гренада",
        "Греція",
        "Грузія",
        "Данія",
        "Джибуті",
        "Домініка",
        "Домініканська Республіка",
        "Еквадор",
        "Екваторіальна Гвінея",
        "Еритрея",
        "Естонія",
        "Ефіопія",
        "Єгипет",
        "Ємен",
        "Замбія",
        "Західна Сахара",
        "Зімбабве",
        "Ізраїль",
        "Індія",
        "Індонезія",
        "Ірак",
        "Іран",
        "Ірландія",
        "Ісландія",
        "Іспанія",
        "Італія",
        "Йорданія",
        "Кабо-Верде",
        "Казахстан",
        "Камбоджа",
        "Камерун",
        "Канада",
        "Катар",
        "Кенія",
        "Киргизстан",
        "КНР",
        "Кіпр",
        "Кірибаті",
        "Колумбія",
        "Коморські Острови",
        "Конго",
        "ДР Конго",
        "Південна Корея",
        "Північна Корея",
        "Косово",
        "Коста-Рика",
        "Кот-д'Івуар",
        "Куба",
        "Кувейт",
        "Лаос",
        "Латвія",
        "Лесото",
        "Литва",
        "Ліберія",
        "Ліван",
        "Лівія",
        "Ліхтенштейн",
        "Люксембург",
        "Маврикій",
        "Мавританія",
        "Мадагаскар",
        "Малаві",
        "Малайзія",
        "Малі",
        "Мальдіви",
        "Мальта",
        "Марокко",
        "Маршаллові Острови",
        "Мексика",
        "Федеративні Штати Мікронезії",
        "Мозамбік",
        "Молдова",
        "Монако",
        "Монголія",
        "М'янма",
        "Намібія",
        "Науру",
        "Непал",
        "Нігер",
        "Нігерія",
        "Нідерланди",
        "Нікарагуа",
        "Німеччина",
        "Нова Зеландія",
        "Норвегія",
        "ОАЕ",
        "Оман",
        "Пакистан",
        "Палау",
        "Палестинська держава",
        "Панама",
        "Папуа Нова Гвінея",
        "ПАР",
        "Парагвай",
        "Перу",
        "Південний Судан",
        "Польща",
        "Португалія",
        "Північна Республіка Македонія",
        "Росія",
        "Руанда",
        "Румунія",
        "Сальвадор",
        "Самоа",
        "Сан-Марино",
        "Сан-Томе і Принсіпі",
        "Саудівська Аравія",
        "Свазіленд",
        "Сейшельські Острови",
        "Сенегал",
        "Сент-Вінсент і Гренадини",
        "Сент-Кіттс і Невіс",
        "Сент-Люсія",
        "Сербія",
        "Сінгапур",
        "Сирія",
        "Словаччина",
        "Словенія",
        "Соломонові Острови",
        "Сомалі",
        "Судан",
        "Суринам",
        "Східний Тимор",
        "США",
        "Сьєрра-Леоне",
        "Таджикистан",
        "Таїланд",
        "Тайвань",
        "Танзанія",
        "Того",
        "Тонга",
        "Тринідад і Тобаго",
        "Тувалу",
        "Туніс",
        "Туреччина",
        "Туркменістан",
        "Уганда",
        "Угорщина",
        "Узбекистан",
        "Україна",
        "Уругвай",
        "Фіджі",
        "Філіппіни",
        "Фінляндія",
        "Франція",
        "Хорватія",
        "Центральноафриканська Республіка",
        "Чад",
        "Чехія",
        "Чилі",
        "Чорногорія",
        "Швейцарія",
        "Швеція",
        "Шрі-Ланка",
        "Ямайка",
        "Японія",
    ]
    street_prefixes = [
        "вулиця",
        "набережна",
        "провулок",
        "площа",
        "проспект",
        "узвіз",
        "сквер",
        "парк",
        "шосе",
    ]

    # https://data.gov.ua/en/dataset/__-120/resource/76e2684f-e75c-45e5-a0b2-6d5596ab47f8
    # https://opendata.drohobych-rada.gov.ua/sites/default/files/%D0%90%D0%B4%D1%80%D0%B5%D1%81%D0%B8%20%D0%94%D1%80%D0%BE%D0%B3%D0%BE%D0%B1%D0%B8%D1%87.xlsx
    street_titles = [
        "1-ша Лінія 4-ї ст. Люстдорфської дороги",
        "1-ша Лінія 6-й ст. Люстдорфської дороги",
        "1-ша Лінія Марії Демченко",
        "Олександра Болдирєва",
        "1-й Академічний тупик",
        "10-та Лінія 6-й ст. Люстдорфської дороги",
        "10-та Лінія Марії Демченко",
        "Олександра Богомольця",
        "11-ша Лінія 6-й ст. Люстдорфської дороги",
        "11-та Лінія Марії Демченко",
        "11-та ст. Великого Фонтану пляж",
        "Яна Длугоша",
        "12-та Лінія 6-й ст. Люстдорфської дороги",
        "12-та ст. Великого Фонтану пляж",
        "Юрія Кондратюка",
        "13-та Лінія 6-й ст. Люстдорфської дороги",
        "13-та ст. Великого Фонтану пляж",
        "Миколи Костомарова",
        "14-та Лінія 6-й ст. Люстдорфської дороги",
        "14-та ст. Великого Фонтану пляж",
        "Марка Крейна",
        "15-та Лінія 6-й ст. Люстдорфської дороги",
        "15-та ст. Великого Фонтану пляж",
        "Скліфосовського",
        "16-та Лінія 6-й ст. Люстдорфської дороги",
        "17-та Лінія 6-й ст. Люстдорфської дороги",
        "18-та Лінія 6-й ст. Люстдорфської дороги",
        "19-та Лінія",
        "19-й км Старокиївської дороги",
        "2-га Лінія 4-ї ст. Люстдорфської дороги",
        "2-га Лінія 6-й ст. Люстдорфської дороги",
        "2-га Лінія Марії Демченко",
        "Бардаха",
        "2-й Академічний тупик",
        "21-й км Старокиївської дороги",
        "3-тя Лінія 4-ї ст. Люстдорфської дороги",
        "3-тя Лінія 6-й ст. Люстдорфської дороги",
        "3-тя Лінія Марії Демченко",
        "Миколи Пильчикова",
        "4-та Лінія 6-й ст. Люстдорфської дороги",
        "4-та Лінія Марії Демченко",
        "Йосипа Фішера",
        "40-річчя оборони Одеси",
        "411-ї батареї",
        "5-та Лінія 6-й ст. Люстдорфської дороги",
        "5-та Лінія Марії Демченко",
        "Цесевича",
        "6-та Лінія 6-й ст. Люстдорфської дороги",
        "6-та Лінія Марії Демченко",
        "Баринштейна",
        "7-ма Лінія 6-й ст. Люстдорфської дороги",
        "7-ма Лінія Дачі Ковалевського",
        "Євгена Крамаренка",
        "8-ма Лінія 6-й ст. Люстдорфської дороги",
        "8-ма Лінія Дачі Ковалевського",
        "Володимира Антоновича",
        "9-та Лінія Дачі Ковалевського",
        "Квітки-Основ’яненка",
        "Абрикосова",
        "Абрикосовий",
        "Авангардна",
        "Одеської громади",
        "Авіаторів",
        "Авіаційна",
        "Аграрна",
        "Агрономічна",
        "Агрономічний",
        "Адміральський",
        "Аеродромна",
        "Аеродромний 1-й",
        "Аеродромний 2-й",
        "Аеродромний 3-й",
        "Аеропортівська",
        "Аеропортівський 1-й",
        "Аеропортівський 2-й",
        "Аеропортівський 3-й",
        "Аеропортівський 4-й",
        "Аеропортівський 5-й",
        "Аеропортівський 6-й",
        "Азербайджан",
        "Азовський",
        "Академіка Богатського",
        "Сергія Єфремова",
        "Академіка Векслера",
        "Карпенка-Карого",
        "Віталія Нестеренка",
        "Житомирська",
        "Князя Ярослава Мудрого",
        "Академіка Заболотного",
        "Академіка Корольова",
        "Дмитра Сигаревича",
        "Академіка Сахарова",
        "Академіка Філатова",
        "Академіка Ясиновського",
        "Академічна",
        "Академічний",
        "Акордна",
        "Алмазна",
        "Альпіністів",
        "Амбулаторна",
        "Амбулаторний",
        "Амбулаторний 1-й",
        "Амбулаторний 2-й",
        "Амундсена, 1-й",
        "Амундсена, 2-й",
        "Амундсена, 3-й",
        "Острозька",
        "Кам’янецький",
        "Глухівський",
        "Волинський",
        "Кременецький",
        "Ананьївська",
        "Буджацька",
        "Андреєвського",
        "Олега Андрійця",
        "Андросовський",
        "Ганни Ахматової",
        "Зої Пасічної",
        "Аптекарський",
        "Аркадіївський",
        "Аркадійська",
        "Аркаса Миколи",
        "Армійська",
        "Артезіанська",
        "Артилерійська",
        "Артилерійський 2-й",
        "Архітекторська",
        "Архітектурна",
        "Юрія Асєєва",
        "Асташкіна",
        "Астрономічна",
        "Астрономічний",
        "Ашгабатська",
        "Дмитра Іванова",
        "Багрицького",
        "Базарна",
        "Байдарочний",
        "Байкал тупик",
        "Юрія Єгорова",
        "Балківська",
        "Балтська дорога",
        "Балтський 1-й",
        "Балтський 2-й",
        "Балтський 3-й",
        "Балтський 4-й",
        "Балтський 5-й",
        "Балтський 6-й",
        "Балтський 7-й",
        "Балтський 8-й",
        "Банний",
        "Баркасний",
        "Басейна",
        "Басейний 1-й",
        "Басейний 2-й",
        "Басейний 3-й",
        "Басейний 4-й",
        "Басейний 6-й",
        "Бахчева",
        "Баштанна",
        "Безіменний",
        "Берегова",
        "Березова",
        "Березовий",
        "Бернардацці",
        "Бессарабська",
        "Данила Самойловича",
        "Бібліотечна",
        "Кастуся Калиновського",
        "Савранський",
        "Біляївська",
        "Ігоря Іванова",
        "Бісквітний",
        "Бітумна",
        "Ольги Благовидової",
        "Богдана Хмельницького",
        "Богуна",
        "Бодаревського",
        "Бокаріуса",
        "Болгарська",
        "Болградська",
        "Бориса Дерев'янка",
        "Бориса Літвака",
        "Героїв Зміїного",
        "Ботанічний",
        "Василя Фащенка",
        "Вінницька",
        "Берестейська",
        "Бреуса Якова",
        "Бригадна",
        "Бугаївська",
        "Будівельна",
        "Будівельний",
        "Бузкова",
        "Бузковий",
        "Бузковий 1-й",
        "Бузковий 2-й",
        "Ніни Строкатої",
        "Бучми",
        "Кінбурнський",
        "В’ячеслава Чорновола",
        "Валіховський",
        "Ванний",
        "Миколи Куліша",
        "Гіацинтовий",
        "Вапняна",
        "Вапняне селище",
        "Вапняний 1-й",
        "Вапняний 2-й",
        "Вапняний 3-й",
        "Варненська",
        "Василя Кандинського",
        "Василя Кандинського 1-й",
        "Василя Кандинського 2-й",
        "Василя Кандинського 3-й",
        "Василя Кандинського 4-й",
        "Василя Кандинського 5-й",
        "Василя Симоненка",
        "Василя Стуса",
        "Ждахи",
        "Михайла Слабченка",
        "Ватманський",
        "Велика Арнаутська",
        "Велика Садова",
        "Венгера",
        "Академіка Липського",
        "Вернидуба",
        "Верстатобудівна",
        "Вертелецького",
        "Верф’яний",
        "Верхня",
        "Вершинна",
        "Весела",
        "Весняна",
        "Ветеранів праці",
        "Назарівська",
        "Ігоря Ветрогонова",
        "Виїзна",
        "Виноградна",
        "Виноградна 1-ша",
        "Виноградна 2-га",
        "Виноградна 3-тя",
        "Виноградний",
        "Виноградний тупик",
        "Висока",
        "Високий",
        "Ярослава Баїса",
        "Виставочна",
        "Вишнева",
        "Вишневий",
        "Відважних",
        "Військовий узвіз",
        "Вільгельма Габсбурга",
        "Віри Інбер",
        "Буковецького",
        "Віри Холодної",
        "Вірського",
        "Вітчизняна",
        "Андрія Гулого-Гуленка",
        "Івана Луценка",
        "Водний",
        "Водопровідна",
        "Водопровідний 1-й",
        "Водопровідний 2-й",
        "Водопровідний 3-й",
        "Вознесенський",
        "Вокзальна",
        "Вокзальний",
        "Олександрійський",
        "тупик Хвиля",
        "Хвиляста",
        "Володимира Вінниченка",
        "Володимира Хавкіна",
        "Володі Дубініна",
        "Батуринська",
        "Ізюмська",
        "Байгородський",
        "Восьмого березня",
        "Восьмого березня 1-й",
        "Восьмого березня 2-й",
        "Восьмого березня 3-й",
        "Восьмого березня 4-й",
        "Кодимський",
        "Восьмого березня 6-й",
        "Бейтельсбахера",
        "Восьмого березня 8-й",
        "Волтона",
        "Восьмого Березня Лінія 1-ша",
        "Килимова",
        "Гобеленова",
        "Фахова",
        "Бондарна",
        "Віктора Скаржинського узвіз",
        "Вузький",
        "Вчительська",
        "Вчительської, 2-й",
        "Гаванна",
        "Газова",
        "Газовий",
        "Павла Клепацького",
        "Давида Бурлюка",
        "Соні Делоне",
        "Андрія Музичка",
        "Гвоздична",
        "Гвоздичний",
        "Гена Іоганна",
        "Генуезька",
        "Геологічна",
        "Георгія Гамова",
        "Геранієва",
        "Героїв Крут",
        "Героїв Небесної Сотні",
        "Героїв оборони Одеси",
        "Героїв прикордонників",
        "Галини Могильницької",
        "Гетьманський",
        "Гілельса",
        "Гімназична",
        "Каменярів",
        "Бориса Нечерди",
        "Дмитра Годзенка",
        "Кафедральна",
        "Глиняна",
        "Глухий міст",
        "Гоголя",
        "Головківська",
        "Головна",
        "Гонтаренко",
        "Горбатий міст",
        "Горбиста",
        "Горизонтальна",
        "Горіхова",
        "Городня",
        "Хортицька",
        "Марка Твена",
        "Госпітальний",
        "Тараса Кузьміна",
        "Гранатна",
        "Гранатний",
        "Грецька",
        "Грецька",
        "Грецький",
        "Джинестрівська",
        "Грузинська",
        "Грузовий",
        "Давида Ойстраха",
        "Трусовська",
        "Дальницька",
        "Дальницьке",
        "Дальній",
        "Дальня",
        "Данила Крижанівського",
        "Проектуєма",
        "Дача Ковалевського",
        "Дачна",
        "Дачний",
        "Дачний 1-й",
        "Дачний 2-й",
        "Всеволода Змієнка",
        "Дев’ята",
        "Деволанівська",
        "Деволанівський узвіз",
        "Миргородський",
        "Дельфін",
        "Грушева",
        "Демократична",
        "Депутатський",
        "Деревообробна",
        "Деревообробний 1-й",
        "Деревообробний 2-й",
        "Деревообробний 3-й",
        "Деревообробний 4-й",
        "Деревообробний 5-й",
        "Глаубермана",
        "Квантовий",
        "Дерибасівська",
        "Десантний",
        "Десята",
        "Десятого квітня",
        "Десятого квітня",
        "Джерельна",
        "Джутовий",
        "Дзвінка",
        "Дігтярна",
        "Дідріхсона",
        "Діхтієвського Віктора",
        "Дмитріївська",
        "Лазурського",
        "Дніпровська",
        "Дніпропетровська дорога",
        "Дністровська",
        "Князя Володимира Великого ",
        "Довга",
        "Довженка",
        "Докова",
        "Долинська",
        "Донецька",
        "Донцова Дмитра",
        "Дорбуду",
        "Дорожня",
        "Друга",
        "Дружний",
        "Дубова",
        "Дубовий гай",
        "Дукова",
        "Біржова",
        "Панаса Саксаганського",
        "Мирослава Скорика",
        "Олександра Кошиця",
        "Лятошинського",
        "Дунайська",
        "Дюківська",
        "Дюківський сад",
        "Економічний",
        "Елеваторна",
        "Естафетна",
        "Естонська",
        "Естонський",
        "Єврейська",
        "Халайджогло",
        "Ференца Ліста",
        "Юрія Коваленка",
        "Охтирський",
        "Єфімова",
        "Жаботинського",
        "Жасминна",
        "Жевахова",
        "Владислава Домбровського",
        "Братів Малакових",
        "Житомирська",
        "Житомирський 3-й",
        "Житомирський 4-й",
        "Жоліо-Кюрі",
        "Жолкова Бориса",
        "Леопольда Ященка",
        "Заводська",
        "Заводська 1-ша",
        "Заводська 2-га",
        "Заводська 3-тя",
        "Заводська 4-та",
        "Заводська 5-та",
        "Задніпровського",
        "Закарпатська",
        "Залізнична",
        "Залізничний 3-й",
        "Заньковецької",
        "Запорізька",
        "Зарічна",
        "Західний 1-й",
        "Західний 2-й",
        "Західний 3-й",
        "Західний 4-й",
        "Зелена",
        "Зелена балка",
        "Зелена гірка",
        "Зелений",
        "Зернова",
        "Злакова",
        "Змієнка Всеволода",
        "Золотий берег",
        "Зоопаркова",
        "Караїмська",
        "Зоряна",
        "Івана Вазова",
        "Івана Микитенка",
        "Івана Франка",
        "Іванівська",
        "Іванівський переїзд",
        "Бутишів",
        "Мерло",
        "Каберне",
        "Іванова Ігоря",
        "Івасюка Володимира",
        "Івахненка Петра",
        "Сім'ї Глодан",
        "Інглезі",
        "Індійська",
        "Сергія Коновалова",
        "Іподромний",
        "Іспанська",
        "Іспанський",
        "Історія Футболу",
        "Італійський",
        "Рабіна Іцхака",
        "Йосипа Тимченка",
        "Кавказька",
        "Кавказький",
        "Кавунова",
        "Ізмаїльська",
        "Казковий",
        "Калинова",
        "Петра Калнишевського",
        "Валерія Самофалова",
        "Кортацці",
        "Камишова",
        "Канатна",
        "Канатний",
        "Капітана Гаврікова",
        "Капітана Кузнецова",
        "Кар’єрна",
        "Карантинна",
        "Карантинний узвіз",
        "Каретний",
        "Каркашадзе",
        "Карпатська",
        "Картамишевська",
        "Картамишевський",
        "Європейська",
        "Каховський",
        "Симфонічна",
        "Каштанова",
        "Квіткова",
        "Квітковий",
        "Квітнева",
        "Кедровий",
        "Керченська",
        "Керченський 1-й",
        "Керченський 2-й",
        "Керченський 3-й",
        "Луїджі Іоріні",
        "Київське",
        "Килимовий",
        "Кипарисний 1-й",
        "Кипарисний 2-й",
        "Кипарисний 3-й",
        "Китобійна",
        "Китобійний 1-й",
        "Китобійний 2-й",
        "Бориса Кифоренка",
        "Кишинівська",
        "Кільовий",
        "Кільцева",
        "Кінна",
        "Ігоря Кисельова",
        "Кладовищенська",
        "Кладовищний",
        "Кленова",
        "Клинова",
        "Ключовий 1-й",
        "Ключовий 2-й",
        "Книжковий",
        "Князівська",
        "Князівський",
        "Павла Зеленого",
        "Пішонівська",
        "Ковиловий",
        "Колективний",
        "Колекційна",
        "Колонічна",
        "Колонтаївська",
        "Василя Капніста",
        "Компасний",
        "Музична",
        "Мелодійний",
        "Ніщинського Композитора",
        "Кондрашина",
        "Конструкторський",
        "Віталія Гуляєва",
        "Кордонна",
        "Кордонний",
        "Корнюшина",
        "Ігоря Балмагії",
        "Короткий",
        "Кобзаря",
        "Косий",
        "Любомира Гузара",
        "Космонавтів",
        "Косовська",
        "Косовський",
        "Костанді",
        "Костанді 2-й",
        "Костанді 3-й",
        "Ольги Благовидової",
        "Олексія Косяченко",
        "Котляревського",
        "Коцюбинського",
        "Кощового отамана",
        "Крайня",
        "Красива",
        "Красний",
        "Краснова",
        "Ольвійська",
        "Краснослобідська",
        "Краснослобідський",
        "Кредитний",
        "Дур'янівський",
        "Кривобалківська",
        "Крижанівський",
        "Юзефа Крашевського",
        "Кримська",
        "Кримський",
        "Кристаловського",
        "Кришталева",
        "Кришталевий",
        "Кропивницького",
        "Кругова",
        "Круговий",
        "Крутоярська",
        "Крушельницької",
        "Кузнечна",
        "Куликове поле",
        "Куликовський 2-й",
        "Куниці",
        "Купріна",
        "Сотника Лугіна",
        "Курортний",
        "Курортний 6-й",
        "Бахмутська",
        "Кустанайська",
        "Кустанайський 2-й",
        "Кутова",
        "Генерала Алмазова",
        "Куяльницький міст",
        "Лавкова",
        "Лазурний 1-й",
        "Лазурний 2-й",
        "Лазурний 3-й",
        "Лазурний 4-й",
        "Лазурний 5-й",
        "Лазурний 6-й",
        "Ламаний",
        "Ланжерон",
        "Ланжеронівська",
        "Ланжеронівський узвіз",
        "Латвійський узвіз",
        "Левадна",
        "Гонсіоровського",
        "Толвінського",
        "Миколи Бурачека",
        "Левкоєва",
        "Олександра Станкова",
        "Олешківська",
        "Леонтовича",
        "Джевецького",
        "Госпітальєрів",
        "Лесі Українки",
        "Леха Качинського",
        "Лиманна",
        "Лиманний",
        "Лиманчик 2-й Лінія 1-ша",
        "Лиманчик 2-й Лінія 11-та",
        "Лиманчик 2-й Лінія 2-га",
        "Лиманчик 2-й Лінія 3-тя",
        "Лиманчик 2-й Лінія 4-та",
        "Лиманчик 2-й Лінія 5-та",
        "Лиманчик 2-й Лінія 8-ма",
        "Лиманчик 2-й Лінія 9-та",
        "Ф. Пішеніна",
        "Липнева",
        "Листяна",
        "Листяний",
        "Литовська",
        "Ліверпульський",
        "Гетьмана Сагайдачного",
        "Шевальових",
        "Лінійна",
        "Лінійний",
        "Лїнія 1-ша",
        "Лінія 22-га",
        "Лінія 23-тя",
        "Лінія 24-та",
        "Лінія 25-та",
        "Лінія 26-та",
        "Лінія 27-ма",
        "Лінія 28-ма",
        "Лінія 29-та",
        "Лінія 30-та",
        "Лінія 31-ша",
        "Лінія 32-га",
        "Лінія 33-тя",
        "Лінія 35-та",
        "Лінія 36-та",
        "Лінія 37-ма",
        "Лінія 38-ма",
        "Лінія 39-та",
        "Лінія 40-ва",
        "Лінія 41-ша",
        "Лінія 42-га",
        "Лінія 43-тя",
        "Лінія 44-та",
        "Лінія 45-та",
        "Лінія 46-та",
        "Лінія 47-ма",
        "Лінія 48-ма",
        "Лінія 49-та",
        "Лінія 50-та",
        "Лінія 51-ша",
        "Лінія 52-га",
        "Лінія 53-тя",
        "Лінія 54-та",
        "Лінія 55-та",
        "Літакова",
        "Літературна",
        "Літній",
        "Літня",
        "Лобачевського",
        "Лодочний",
        "Локальна",
        "Локомотивна",
        "Локомотивний 1-й",
        "Локомотивний 2-й",
        "Локомотивний 3-й",
        "Локомотивний 4-й",
        "Луганська",
        "Лугова",
        "Лузанівка",
        "Лузанівка",
        "Лузанівська",
        "Лузанівський",
        "Лузанівський 1-й",
        "Лузанівський 2-й",
        "Місячний",
        "Луценка Івана",
        "Луцька",
        "Лучиста",
        "Льва Симиренка",
        "Менделе Сфоріма",
        "Львівська",
        "Львівський",
        "Любашівський",
        "Людмили Гінзбург",
        "Люстдорфська дорога",
        "Люстдорфський",
        "Лютеранський",
        "Лютнева",
        "Лютневий 1-й",
        "Лютневий 2-й",
        "Хортицька",
        "Остапа Вишні",
        "Олександра Ройтбурда",
        "М’ясоєдовська",
        "Магістральна",
        "Михайла Врубеля",
        "Адольфа Лози",
        "Сергія Параджанова",
        "Мазепи Івана",
        "Майстерний",
        "Лігінська",
        "Контрадмірала Остроградського",
        "Макова",
        "Маковий",
        "Мала",
        "Мала Арнаутська",
        "Мала Садова",
        "Маланова",
        "Хаджибейський",
        "Маловського",
        "Манежна",
        "Манежний",
        "Маразліївська",
        "Фруктова",
        "Сливовий",
        "Чорничний",
        "узвіз Віталія Блажка",
        "Мариністів",
        "Дениса Максишка",
        "Михайла Омеляновича-Павленка",
        "Марсельська",
        "Добровольців",
        "Маршрутна",
        "Матеріальний 1-й",
        "Матроська Слободка ",
        "Матроський узвіз",
        "Матюшенка",
        "Віталія Блажка",
        "Мацієвської",
        "Мацієвської узвіз",
        "Машинобудівний",
        "Маячний",
        "Мелітопольська",
        "Мельницька",
        "Металістів",
        "Флейтовий",
        "Петра Болбочана",
        "Мечникова",
        "Мигдальна",
        "Миколаївська дорога",
        "Миколаївський 1-й",
        "Миколи Бажана",
        "Миколи Боровського",
        "Миколи Вороного",
        "Ганса Германа",
        "Миколи Гумільова",
        "Миколи Огренича",
        "Миколи Плигуна",
        "Мирна",
        "Митна",
        "Митракова",
        "Михайла Божія",
        "Михайла Грушевського",
        "Військово-морських сил",
        "Михайлівська",
        "Йозефа Прибіка",
        "Місячна",
        "Миколи Міхновського",
        "Міцкевича",
        "Матроський",
        "Бєлякова",
        "Волова",
        "Могилівська",
        "Молоді",
        "Молодіжна",
        "Чайкова",
        "Молокова",
        "Монастирський",
        "Монгольська",
        "Морехідна",
        "Морехідний",
        "Морська",
        "Морський",
        "Морський 2-й",
        "Литавровий",
        "Москеті",
        "Мостовий",
        "Моторна",
        "Моторний 1-й",
        "Моторний 2-й",
        "Моторний 3-й",
        "Мукачівський",
        "Мусіна",
        "Набережна",
        "Навігаційний",
        "Надіїі",
        "Наклонна",
        "Наливна",
        "Нафтовиків",
        "Нафтовиків",
        "Нафтовиків 1-й",
        "Нафтовиків 2-й",
        "Нафтовиків 3-й",
        "Миколи Кравченка",
        "Наявний 1-й",
        "Наявний 2-й",
        "Наявний 3-й",
        "Наявний 4-й",
        "Наявний 5-й",
        "Наявний 6-й",
        "Наявний 7-й",
        "Небесної Сотні",
        "Анатолія Бачинського",
        "Заможна",
        "Ромський",
        "Незалежності",
        "Отонівський",
        "Немировича-Данченка",
        "Неплія",
        "Нерубайська",
        "Нескучна",
        "Нечипуренка",
        "Ніжинська",
        "Шполянська",
        "Нова",
        "Новаторів",
        "Михайла Жука",
        "Дворникова",
        "Теофіла Фраєрмана",
        "Новий",
        "Новиков міст",
        "Ірини Жиленко",
        "Родоканакі",
        "Новобазарний",
        "Новоберегова",
        "Чигиринська",
        "Новоселів",
        "Новосельского",
        "Новоукраїнський",
        "Новощіпний ряд",
        "Об'їзна дорога",
        "Обільна",
        "Обільний 1-й",
        "Обільний 2-й",
        "Обривиста",
        "Обсерваторний",
        "Овідіопольська",
        "Овідіопольська дорога",
        "Овідіопольська дуга",
        "Овідіопольський",
        "Одарія",
        "Одеса-Головна",
        "Одеська",
        "Одеський",
        "Озерна",
        "Окружна",
        "Олександра Блока",
        "Композитора Вербицького",
        "Олександра Кутузакія",
        "Валерія Лобановського",
        "Сергія Шелухина",
        "Климовича",
        "Чехівського",
        "Василя Кричевського",
        "Павла Чубинського",
        "Майка Йогансена",
        "Леоніда Осики",
        "Олександра Тимошенка",
        "Українських Героїв",
        "Олексіївська",
        "Ольгіївська",
        "Ольгіївський узвіз",
        "Василя Берладяну",
        "Евлії Челебі",
        "Онілової",
        "Оранжерейний",
        "Орликова",
        "Олешківська",
        "Надії Пучковської",
        "Осипова",
        "Осіння",
        "Остапа Вишні",
        "Отамана Головатого",
        "Отамана Чепіги",
        "Отрада",
        "Отрадна",
        "Офіцерська",
        "Офіцерський 1-й",
        "Офіцерський 2-й",
        "П'ята",
        "Пiвденний",
        "Павла Кравцова",
        "Павла Шклярука",
        "Павлова",
        "Павлодарська",
        "Палія Семена",
        "Палубна",
        "Палубний",
        "Панаса Мирного",
        "Пантелеймонівська",
        "Панченка",
        "Парашутний",
        "Паркова",
        "Парковий",
        "Партизанська",
        "Партизанської слави",
        "Парусна",
        "Пассіонарії",
        "Пастера",
        "Патріотична",
        "Педагогічна",
        "Педагогічний",
        "Пейзажна",
        "Добровольців",
        "Рятувальників",
        "Перепечка",
        "Пересипський міст",
        "Пересипська 1-ша",
        "Пересипська 10-та",
        "Пересипська 2-га",
        "Пересипська 3-тя",
        "Пересипська 4-та",
        "Пересипська 5-та",
        "Пересипська 6-та",
        "Пересипська 7-ма",
        "Пересипська 8-ма",
        "Пересипська 9-та",
        "Пересипський 1-й",
        "Пересипський 2-й",
        "Пересипський узвіз",
        "Перлинна",
        "Перша",
        "Перший Кришталевий",
        "Миколи Леонтовича",
        "Саймона Літмана",
        "Цукровий",
        "Петра Лещенка",
        "Леся Курбаса",
        "Пироговська",
        "Пироговський",
        "Бориса Едуардса",
        "Південна",
        "Південна дорога",
        "Південно-Санаторний",
        "Північна",
        "Північний",
        "Підйомний",
        "Пілотна",
        "Пісочна",
        "Пісочний",
        "Пішонівська",
        "Планетна",
        "Платанова",
        "Бродська",
        "Пляжна",
        "Побратимів",
        "Подільська",
        "Поїзна",
        "Покровський",
        "Буковинська",
        "Хотинський",
        "Політкаторжан",
        "Полтавська",
        "Полуничний",
        "Польова",
        "Польовий 1-й",
        "Польська",
        "Польський узвіз",
        "Поперечний",
        "Посівна",
        "Балтиморська",
        "Поштова",
        "Поштовий",
        "Преображенська",
        "Пресича Олександра",
        "Стрийський",
        "Прибережний",
        "Привозна",
        "Привокзальна",
        "Привокзальний",
        "Приморська",
        "Приморський",
        "Приморський",
        "Прирейкова",
        "Проектна 1-ша",
        "Проектна 2-га",
        "Проектний 5-й",
        "Проектований 3-й",
        "Проектований 4-й",
        "Проїзний 1-й",
        "Проїзний 2-й",
        "Проїзний 3-й",
        "Прокатна",
        "Іони Отаманського",
        "Географічний",
        "Промислова",
        "Промисловий",
        "Прорізна",
        "Прорізний",
        "Просвіти",
        "Путівна",
        "Проточний",
        "Професора Каришковського",
        "Професора Коровицького",
        "Профспілкова",
        "Прохоровська",
        "Прохоровський",
        "Прохоровський",
        "Проценка",
        "Почаївська",
        "Опішнянський",
        "Персикова",
        "Путьова",
        "Рози вітрів",
        "Пшенична",
        "Прилуцький",
        "Радіальна",
        "Радіальний",
        "Радіо",
        "Радісна",
        "Радісний",
        "Разумовська",
        "Раїси Сергієнко",
        "Райдужна",
        "Ракетна",
        "Рачкова",
        "Регенсбург",
        "Рекордний",
        "Рельєфна",
        "Ремонтна",
        "Республіканська",
        "Рєпіна",
        "Рибальська",
        "Рибальська балка",
        "Рибальський",
        "Ризька",
        "Рівний",
        "Рівності",
        "Рівності",
        "Рівності 1-й",
        "Рівності 2-й",
        "Різдвяна",
        "Різницький",
        "Різовська",
        "Рішельєвська",
        "Рожева",
        "Роздольна",
        "Розкидайлівська",
        "Розумовський 1-й",
        "Розумовський 2-й",
        "Решата Аметова",
        "Романтиків",
        "Романтичний",
        "Ромашкова",
        "Маріупольська",
        "Гайова",
        "Рульовий",
        "Миколи Савича",
        "Сабанський",
        "Савицький",
        "Савранська",
        "Садиковська",
        "Садова",
        "Садова 1-ша",
        "Садова 2-га",
        "Садова 3-тя",
        "Садова 4-та",
        "Садова 5-та",
        "Садова 6-та",
        "Садовий",
        "Садовського",
        "Саксаганського",
        "Пилипа Орлика",
        "Обліпихова",
        "Самодіяльна",
        "Санаторний",
        "Санітарна",
        "Сашка Хорошенка",
        "Світанку",
        "Світла",
        "Світлий",
        "Свободи",
        "Святослава Ріхтера",
        "Севастопольський",
        "Сегедська",
        "Селекційна",
        "Селекційний",
        "Селищна",
        "Селищний",
        "Семафорний",
        "Семінарська",
        "Сергія Ейзенштейна",
        "Сергія Уточкіна",
        "Сергія Ядова",
        "Серединський",
        "Середньофонтанська",
        "Середньофонтанський",
        "Середня",
        "Сірожупанників",
        "Сєрогодського",
        "Зої Бутенко",
        "Поліська",
        "Сирітський",
        "Сирітський 2-й",
        "Сільська",
        "Сільськогосподарський",
        "Сімферопольська",
        "Сінна",
        "Новопланівська",
        "Скидановська",
        "Скидановський узвіз",
        "Складська",
        "Скляна",
        "Скляний 1-й",
        "Скляний 2-й",
        "Скляний 3-й",
        "Скрипковий",
        "Слави",
        "Слави",
        "Донорська",
        "Сливова",
        "Слобідська",
        "Слобідський узвіз",
        "Слов'янська",
        "Сміливий",
        "Почаївська",
        "Павла Вірського",
        "Соборна",
        "Совіньйонівський",
        "Солонцюватий",
        "Солонцюватий 1-й",
        "Соляна",
        "Соляний 1-й",
        "Соляний 2-й",
        "Соляний 3-й",
        "Соляний 4-й",
        "Соляний 5-й",
        "Соляний 6-й",
        "Соляний 7-й",
        "Сонячна",
        "Сортувальна 1-ша",
        "Сортувальна 2-га",
        "Сосюри",
        "Софії Перовської",
        "Софіївська",
        "Соціальна",
        "Бахчисарайська",
        "Ярмарковий",
        "Спаський",
        "Спиридонівська",
        "Спортивна",
        "Спортивний",
        "Сталепрокатна",
        "Стамбульський",
        "Станційна 1-ша",
        "Станційна 2-га",
        "Станційна 3-тя",
        "Старицького",
        "Старобазарний",
        "Старокінний",
        "Старопортофранківська",
        "Старорізнична",
        "Старосінна",
        "Школярський",
        "Стельмаха",
        "Степана Олійника узвіз",
        "Малинова",
        "Степна",
        "Степний 2-й",
        "Степова",
        "Стеценко",
        "Томатна",
        "Стовпова",
        "Стороженка Олега",
        "Стражеска Миколи",
        "Строганов міст",
        "Максима Чайки",
        "Студена",
        "Студентський",
        "Студентський 1-й",
        "Студентський 2-й",
        "Студентський 3-й",
        "Студентський 4-й",
        "Студентський 5-й",
        "Петра Біциллі",
        "Суднобудівна",
        "Суднобудівний",
        "Сумська",
        "Сумський",
        "Суперфосфатна",
        "Супутників",
        "Лірний",
        "Бандурний",
        "Сухолиманна",
        "Східний",
        "Східний 1-й",
        "Східний 2-й",
        "Східчастий 3-й",
        "Східчастий 4-й",
        "Східчастий",
        "Сьома",
        "Таїрова",
        "Танкерна",
        "Танкістів",
        "Танфільєва",
        "Тарутинська",
        "Творча",
        "Текстильників",
        "Олени Теліги",
        "Тепла",
        "Теплична",
        "Тепличний 1-й",
        "Тепличний 2-й",
        "Володимира Терещенка",
        "Тетяни Тесс",
        "Технічний",
        "Тещин міст",
        "Айвазовського",
        "Тираспольська",
        "Тиха",
        "Тіниста",
        "Тінистий",
        "Ткачова",
        "Товарний",
        "Трибуни героїв",
        "Георгія Липського",
        "Василя Данилевича",
        "Тополина",
        "Тополиний",
        "Топольського",
        "Торгова",
        "Травневий",
        "Травневий 1-й",
        "Травневий 2-й",
        "Травневий 3-й",
        "Травневий 4-й",
        "Травневий 5-й",
        "Тракторна",
        "Трамвайна",
        "Трамвайний",
        "Транспортна",
        "Траса Здоров'я",
        "Троїцька",
        "Миколи Троїцького",
        "Тролейбусна",
        "Трояндова",
        "Трудова",
        "Трудовий",
        "Олександра Білостінного",
        "Героїв УПА",
        "Тупиковий",
        "Тупиковий 1-й",
        "Тупиковий 2-й",
        "Андрія Сови",
        "Туристська",
        "Туристський",
        "Тюльпанний",
        "Угорська",
        "Удільний",
        "Українська",
        "Український 1-й",
        "Український 2-й",
        "Український 3-й",
        "Улицька",
        "Уманська",
        "Умова",
        "Університетський",
        "Уральська",
        "Уральський",
        "Урожайна",
        "Усатівська",
        "Успенська",
        "Успенський",
        "Ніли Крюкової",
        "Училищна",
        "Учительський",
        "Учнівська",
        "Багринова",
        "Ушинського",
        "Затишна",
        "Ф. Пішеніна",
        "Фабрична",
        "Фестивальний",
        "Флотська",
        "Флотський 1-й",
        "Флотський 2-й",
        "Флотський 3-й",
        "Флотський 4-й",
        "Фонтанська дорога",
        "Французький",
        "Фруктовий",
        "Хаджибейська дорога",
        "Хаджибейський 1-й",
        "Хаджибейський 2-й",
        "Хаджибейський 3-й",
        "Харківська",
        "Хвойний",
        "Херсонський",
        "Херсонський сквер",
        "Хімічна",
        "Хімічний 1-й",
        "Хімічний 2-й",
        "Хімічний 3-й",
        "Хлібна гавань",
        "Художника Федорова",
        "Хутірська",
        "Хутірський",
        "Цебриківська",
        "Цегельнозаводська",
        "Цегляна",
        "Цементний",
        "Центральна",
        "Центральний аеропорт",
        "Церковна",
        "Цимлянська",
        "Йоганна Ансельма",
        "Театральний",
        "Барвінковий",
        "Черешнева",
        "Черкаська",
        "Чернишевського",
        "Чернівецький",
        "Чернігівська",
        "Чернігівський",
        "Артура Савельєва",
        "Четверта",
        "Журавлина",
        "Чорноморка",
        "Чорноморська",
        "Чорноморський",
        "Чорноморський",
        "Чорноморський 1-й",
        "Чорноморський 10-й",
        "Чорноморський 11-й",
        "Чорноморський 12-й",
        "Чорноморський 13-й",
        "Чорноморський 2-й",
        "Чорноморський 3-й",
        "Чорноморський 4-й",
        "Чорноморський 5-й",
        "Чорноморський 6-й",
        "Чорноморський 7-й",
        "Чорноморський 8-й",
        "Чорноморський 9-й",
        "Чорноморського козацтва",
        "Чубаївська",
        "Чубаївський",
        "Чумацька",
        "Шампанський",
        "Шахтинський",
        "Шебелінський",
        "Шевченка",
        "Шевченка парк",
        "Шептицького",
        "Шефська",
        "Шилова",
        "В'ячеслава Липинського",
        "Ширяївський",
        "Незамаївська",
        "Олександра Мурашка",
        "Шкільний",
        "Шкільний аеродром",
        "Шкіперська",
        "Шкодова гора",
        "Шовкуненка",
        "Волокидіна",
        "Шоста",
        "Шостої 1-й",
        "Шостої 2-й",
        "Шота Руставелі",
        "Штабний",
        "Штильова",
        "Штурвальна",
        "Штурманська",
        "Шухевича Романа",
        "Щіпний",
        "Щоглова",
        "Щоголєва",
        "Медовий",
        "Ювілейний 1-й",
        "Ювілейний 2-й",
        "Юннатів",
        "Юннатів 1-й",
        "Юннатів 2-й",
        "Юннатів 3-й",
        "Олександра Юрженка",
        "Юрія Олеші",
        "Юрія Яновського",
        "Юхима Геллера",
        "Юхима Фесенка",
        "Альтовий",
        "Яблунева",
        "Яблучна",
        "Якірний",
        "Ігоря Бедзая",
        "Ялинкова",
        "Ялинковий",
        "Ігоря Бедзая",
        "Ямчитського",
        "Ярморочна площа",
        "Яружний",
        "Ясна",
        "Семена Яхненка",
        "Яші Гордієнка",
    ]

    def city_prefix(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.city_prefixes)

    def city_name(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.city_names)

    def postcode(self) -> str:
        """
        The code consists of five digits (01000-99999)

        :sample:
        """
        return f"{self.generator.random.randrange(1000, 99999):05}"

    def street_prefix(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.street_prefixes)

    def street_name(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.street_titles)

    def street_title(self) -> str:
        """
        :sample:
        """
        prefix = self.street_prefix()
        street = self.street_name()
        return prefix + " " + street

    def region(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.region_names)



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    # Source: https://de.wikipedia.org/wiki/Firma#Schweizerisches_Recht

    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
    )

    company_suffixes = (
        "AG",
        "AG",
        "AG",
        "GmbH",
        "GmbH",
        "GmbH",
        "& Co.",
        "& Partner",
        "& Cie.",
        "& Söhne",
    )



from collections import OrderedDict
from typing import Optional

from faker.providers.person.ru_RU import translit
from faker.typing import CardType, CreditCard

from .. import Provider as CreditCardProvider


class Provider(CreditCardProvider):
    """Implement credit card provider for ``ru_RU`` locale.

    For all methods that take ``card_type`` as an argument, a random card type
    will be used if the supplied value is ``None``. The list of valid card types
    includes ``'amex'``, ``'maestro'``, ``'mastercard'``, ``'mir'``,
    ``'unionpay'``, and ``'visa'``.

    Sources:

    - https://en.wikipedia.org/wiki/Payment_card_number#Issuer_identification_number_(IIN)
    """

    prefix_visa = ["4"]
    prefix_mastercard = [
        "51",
        "52",
        "53",
        "54",
        "55",
        "222%",
        "223",
        "224",
        "225",
        "226",
        "227",
        "228",
        "229",
        "23",
        "24",
        "25",
        "26",
        "270",
        "271",
        "2720",
    ]
    prefix_mir = ["2200", "2201", "2202", "2203", "2204"]
    prefix_maestro = [
        "50",
        "56",
        "57",
        "58",
        "59",
        "60",
        "61",
        "62",
        "63",
        "64",
        "65",
        "66",
        "67",
        "68",
        "69",
    ]
    prefix_amex = ["34", "37"]
    prefix_unionpay = ["62", "81"]

    credit_card_types = OrderedDict(
        (
            ("visa", CreditCard("Visa", prefix_visa, security_code="CVV2")),
            (
                "mastercard",
                CreditCard("Mastercard", prefix_mastercard, security_code="CVC2"),
            ),
            ("mir", CreditCard("МИР", prefix_mir)),
            ("maestro", CreditCard("Maestro", prefix_maestro, security_code="CVV2")),
            (
                "amex",
                CreditCard(
                    "American Express",
                    prefix_amex,
                    15,
                    security_code="CID",
                    security_code_length=4,
                ),
            ),
            ("unionpay", CreditCard("Union Pay", prefix_unionpay)),
        )
    )

    def credit_card_full(self, card_type: Optional[CardType] = None) -> str:
        """Generate a set of credit card details."""
        card = self._credit_card_type(card_type)

        tpl = "{provider}\n{owner}\n{number} {expire_date}\n{security}: {security_nb}\n{issuer}"

        tpl = tpl.format(
            provider=card.name,
            owner=translit(
                self.generator.parse(
                    self.random_element(
                        [
                            "{{first_name_male}} {{last_name_male}}",
                            "{{first_name_female}} {{last_name_female}}",
                        ]
                    )
                )
            ),
            number=self.credit_card_number(card),
            expire_date=self.credit_card_expire(),
            security=card.security_code,
            security_nb=self.credit_card_security_code(card),
            issuer=self.generator.parse("{{bank}}"),
        )

        return self.generator.parse(tpl)



from typing import Tuple

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female: Tuple[str, ...] = ("{{first_name_female}} {{last_name}}",)

    formats_male: Tuple[str, ...] = ("{{first_name_male}} {{last_name}}",)

    formats = formats_male + formats_female

    # Translated from: https://studentsoftheworld.info/penpals/stats_fr.php?Pays=ALG
    # Last checked: 2025-09-28
    first_names_female: Tuple[str, ...] = (
        "آية",
        "أماني",
        "أمل",
        "أمينة",
        "أميرة",
        "أناييس",
        "أنيسة",
        "أسماء",
        "إكرام",
        "إيمان",
        "إيناس",
        "بشرى",
        "تينهينان",
        "حياة",
        "خديجة",
        "داليا",
        "دنيا",
        "رانية",
        "رشا",
        "روز",
        "ريم",
        "ريما",
        "زينة",
        "زينب",
        "سارة",
        "سعاد",
        "سرين",
        "سلمى",
        "سليمة",
        "سميرة",
        "سومية",
        "سيليا",
        "سيلين",
        "شيراز",
        "صبرينة",
        "صفية",
        "صوفيا",
        "فاطمة",
        "فرح",
        "فريال",
        "فوزية",
        "فلة",
        "كاتيا",
        "كاهينة",
        "ليديا",
        "ليزا",
        "ليلى",
        "ليليا",
        "ليندة",
        "لينا",
        "ماريا",
        "مايا",
        "ملاك",
        "مروة",
        "مريم",
        "مزرية",
        "مينة",
        "ميرا",
        "ميليسا",
        "نادية",
        "نسرين",
        "نجمة",
        "نريمان",
        "نوال",
        "نهاد",
        "نور",
        "هاجر",
        "هانية",
        "هدى",
        "هناء",
        "وفاء",
        "ياسمين",
        "ياسمينة",
        "يسرى",
    )

    # Translated from: https://studentsoftheworld.info/penpals/stats_fr.php?Pays=ALG
    # Last checked: 2025-09-28
    first_names_male: Tuple[str, ...] = (
        "آدم",
        "أسامة",
        "أحمد",
        "أرزقي",
        "أكرم",
        "أمين",
        "أمير",
        "أنيس",
        "أيمن",
        "أيوب",
        "إبراهيم",
        "إلياس",
        "عبد الرحمن",
        "عبد الرؤوف",
        "عبد القادر",
        "علاء الدين",
        "عادل",
        "علي",
        "عمر",
        "فاتح",
        "فارس",
        "فاروق",
        "فريد",
        "فرحات",
        "فضيل",
        "غِلاس",
        "قادة",
        "خالد",
        "خليل",
        "رابح",
        "رضا",
        "رشدي",
        "رشيد",
        "رمزي",
        "رياض",
        "زكريا",
        "سعد",
        "سعيد",
        "سامي",
        "سمير",
        "سفيان",
        "سليم",
        "صالح",
        "شعبان",
        "شريف",
        "طه",
        "علي",
        "علاء الدين",
        "غِلاس",
        "قادة",
        "لطفي",
        "لمين",
        "مالك",
        "ماسِينيسا",
        "مراد",
        "محند",
        "محمد",
        "مصطفى",
        "منير",
        "مهدي",
        "مولود",
        "موسى",
        "ناصر",
        "ناظم",
        "نادر",
        "نسيم",
        "وليد",
        "وسيم",
        "وناس",
        "ياسر",
        "ياسين",
        "يانيس",
        "يحيى",
        "يوسف",
        "يونس",
        "يوبا",
    )

    first_names = first_names_male + first_names_female

    # Translated from: https://fr.geneawiki.com/wiki/Noms_de_famille_alg%C3%A9riens
    # Last checked: 2025-09-28
    last_names: Tuple[str, ...] = (
        "أعراب",
        "إبراهيمي",
        "إخلف",
        "إسماعيل",
        "باشا",
        "باي",
        "بحري",
        "بختي",
        "بخوش",
        "بغدادي",
        "بركان",
        "بركاني",
        "بلبشير",
        "بلحاج",
        "بلخير",
        "بلخيري",
        "بلعربي",
        "بلعيد",
        "بلعيدي",
        "بلقادي",
        "بلقاسم",
        "بلقاسمي",
        "بن أحمد",
        "بن زيان",
        "بن سالم",
        "بن سعيد",
        "بن سليمان",
        "بن شيخ",
        "بن صالح",
        "بن عامر",
        "بن عبد الله",
        "بن علي",
        "بن عمار",
        "بن عمارة",
        "بن عودة",
        "بن عيسى",
        "بن موسى",
        "بن يحيى",
        "بن يمينة",
        "بن يوسف",
        "بو عافية",
        "بو عبد الله",
        "بوبكر",
        "بوتالب",
        "بوجمعة",
        "بوخاتم",
        "بوخاري",
        "بوخلفة",
        "بودراع",
        "بوزيان",
        "بوزيد",
        "بوزيدي",
        "بوسعيد",
        "بوشامة",
        "بوشارب",
        "بوعزيز",
        "بوعلام",
        "بوعلي",
        "بومدين",
        "بومعزة",
        "بوناب",
        "تابت",
        "تومي",
        "تواتي",
        "جبار",
        "جلال",
        "جلولي",
        "جودي",
        "داود",
        "داوودي",
        "دحمان",
        "دحماني",
        "دراجـي",
        "دربال",
        "دركاوي",
        "درويش",
        "ديب",
        "دياف",
        "ديف",
        "رابحي",
        "رحال",
        "رحمون",
        "رحماني",
        "رحموني",
        "ربيعة",
        "رشدي",
        "رزّيق",
        "رمضاني",
        "زايدي",
        "زاوي",
        "زروال",
        "زرّوقي",
        "زواوي",
        "زيان",
        "زياني",
        "زيتوني",
        "زيدان",
        "ساسي",
        "سالم",
        "سالمي",
        "سعد",
        "سعدي",
        "سعودي",
        "سعيد",
        "سعيداني",
        "سعيدي",
        "سلامي",
        "سلطاني",
        "سليماني",
        "سهلي",
        "سوداني",
        "سياح",
        "شايب",
        "شاوي",
        "شريف",
        "شريفي",
        "شرقي",
        "شعبان",
        "شعيباني",
        "شيخ",
        "صالح",
        "صالحي",
        "صحراوي",
        "صدِّيقي",
        "طالب",
        "طالبي",
        "طايبي",
        "طحراوي",
        "طهري",
        "طويل",
        "عثماني",
        "فارس",
        "فرحات",
        "فلاح",
        "فيلالي",
        "قاسم",
        "قاسمي",
        "قاسي",
        "قبائلي",
        "قدور",
        "قدوري",
        "قرفي",
        "قريشي",
        "قندوز",
        "قويدري",
        "لحمر",
        "لخضر",
        "لعربي",
        "لعريبي",
        "لعمري",
        "لوسيف",
        "لونيس",
        "ماحي",
        "ماعوش",
        "مالك",
        "مالكي",
        "مباركي",
        "مخلوف",
        "مخلوفي",
        "مداح",
        "مداني",
        "مداهد",
        "مرابط",
        "مراح",
        "مرزوق",
        "مرزوقي",
        "مرسلي",
        "مزيان",
        "مزياني",
        "مسعودي",
        "مشري",
        "مصباح",
        "مصطفاوي",
        "مفتاح",
        "مقدم",
        "مقران",
        "مقراني",
        "محمدي",
        "محمودي",
        "مختاري",
        "معزوز",
        "معزوزي",
        "ميلودي",
        "ميموني",
        "ميهوبي",
        "مولاي",
        "موساوي",
        "موسى",
        "نايلي",
        "ناصر",
        "نجار",
        "نصري",
        "نوار",
        "نوري",
        "نوي",
        "هاشمي",
        "هني",
        "هواري",
        "يحبَوي",
        "يحيى",
        "يوسفي",
    )



from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # Source: https://vi.wikipedia.org/wiki/%C4%90%E1%BB%93ng_(%C4%91%C6%A1n_v%E1%BB%8B_ti%E1%BB%81n_t%E1%BB%87)#Ti%E1%BB%81n_gi%E1%BA%A5y_-_Ti%E1%BB%81n_polymer  # NOQA
    price_formats = ["#.##", "%#.##", "%##.##", "%,###.##", "%#,###.##"]

    def pricetag(self) -> str:
        return "₫" + self.numerify(self.random_element(self.price_formats))



from .. import Provider as CurrencyProvider


class Provider(CurrencyProvider):
    # Source https://el.wikipedia.org/wiki/Κατάλογος_νομισμάτων_των_χωρών_του_κόσμου
    # Format: (code, name)
    currencies = (
        ("AED", "Ντιρχάμ των Ηνωμένων Αραβικών Εμιράτων"),
        ("AFN", "Αφγάνι"),
        ("ALL", "Λεκ"),
        ("AMD", "Ντραμ"),
        ("AOA", "Κουάνζα"),
        ("ARS", "Πέσο Αργεντινής"),
        ("AUD", "Δολάριο Αυστραλίας"),
        ("AZN", "Μανάτ του Αζερμπαϊτζάν"),
        ("BAM", "Μετατρέψιμο μάρκο Βοσνίας και Ερζεγοβίνης"),
        ("BBD", "Δολάριο των Μπαρμπάντος"),
        ("BDT", "Τάκα"),
        ("BGN", "Λεβ"),
        ("BHD", "Δηνάριο του Μπαχρέιν"),
        ("BIF", "Φράγκο του Μπουρούντι"),
        ("BND", "Κυάτ Μιανμάρ"),
        ("BOB", "Μπολιβιάνο"),
        ("BRL", "Ρεάλ Βραζιλίας"),
        ("BSD", "Δολάριο Μπαχάμας"),
        ("BTN", "Νγκούλντρουμ"),
        ("BWP", "Πούλα"),
        ("BYΝ", "Ρούβλι Λευκορωσίας"),
        ("BZD", "Δολάριο Μπελίζ"),
        ("CAD", "Δολάριο Καναδά"),
        ("CDF", "Φράγκο του Κονγκό"),
        ("CHF", "Ελβετικό Φράγκο"),
        ("CLP", "Πέσο Χιλής"),
        ("CNY", "Γιουάν |"),
        ("COP", "Πέσο Κολομβίας"),
        ("CRC", "Κολόν"),
        ("CSD", "Δηνάριο Σερβίας"),
        ("CUC", "Μετατρέψιμο πέσο Κούβας"),
        ("CUP", "Πέσος Κούβας"),
        ("CVE", "Εσκούδο Πρασίνου Ακρωτηρίου"),
        ("CZK", "Κορόνα Τσεχίας (koruna)"),
        ("DJF", "Φράγκο του Τζιμπουτί"),
        ("DKK", "Κορόνα Δανίας"),
        ("DOP", "Πέσο Δομινικανής Δημοκρατίας"),
        ("DZD", "Δηνάριο της Αλγερίας"),
        ("EGP", "Λίρα Αιγύπτου"),
        ("ERN", "Νάκφα"),
        ("ETB", "Μπιρ"),
        ("EUR", "Ευρώ"),
        ("FJD", "Δολάριο Νησιών Φίτζι"),
        ("GBP", "Στερλίνα"),
        ("GEL", "Λάρι"),
        ("GHC", "Σέντι της Γκάνας"),
        ("GMD", "Νταλάζι (Dalasi)"),
        ("GNF", "Φράγκο Γουινέας"),
        ("GTQ", "Κετσάλ"),
        ("GYD", "Δολάριο Γουιάνας"),
        ("HNL", "Λεμπίρα"),
        ("HRK", "Κούνα"),
        ("HTG", "Γκουρντ"),
        ("HUF", "Φιορίνι Ουγγαρίας"),
        ("IDR", "Ρουπία Ινδονησίας"),
        ("ILS", "Νέο σέκελ"),
        ("INR", "Ρουπία Ινδίας[6]"),
        ("IQD", "Δηνάριο του Ιράκ"),
        ("IRR", "Ριάλ του Ιράν"),
        ("ISK", "Κορόνα Ισλανδίας (króna)"),
        ("JMD", "Δολάριο Τζαμάικας"),
        ("JOD", "Ιορδανικό δηνάριο"),
        ("JPY", "Γιέν"),
        ("KES", "Σελίνι Κένυας"),
        ("KGS", "Σομ της Κιργιζίας"),
        ("KHR", "Ριέλ Καμπότζης"),
        ("KMF", "Φράγκο Κομόρων"),
        ("KPW", "Γουόν Βόρειας Κορέας"),
        ("KRW", "Γουόν Νότιας Κορέας"),
        ("KWD", "Δηνάριο του Κουβέιτ"),
        ("KZT", "Τένγκε"),
        ("LAK", "Κιπ"),
        ("LBP", "Λίρα Λιβάνου"),
        ("LKR", "Ρουπία της Σρι Λάνκας (rupee)"),
        ("LRD", "Δολάριο Λιβερίας"),
        ("LSL", "Λότι"),
        ("LYD", "Δηνάριο Λιβύης"),
        ("MAD", "Ντιρχάμ Μαρόκου"),
        ("MDL", "Μολδαβικό Λέου"),
        ("MGA", "Αριάρι[10]"),
        ("MKD", "Δηνάριο Βόρειας Μακεδονίας"),
        ("MNT", "Τουγκρίκ"),
        ("MRU", "Ουγκίγια[10]"),
        ("MUR", "Ρουπία Μαυρίκιου"),
        ("MVR", "Ρουφίγια"),
        ("MWK", "Κουάτσα του Μαλάουι"),
        ("MXN", "Πέσο Μεξικού"),
        ("MYR", "Ρινγκίτ"),
        ("MZN", "Μετικάλ"),
        ("NAD", "Δολάριο Ναμίμπιας"),
        ("NGN", "Νάιρα"),
        ("NIO", "Χρυσό κόρντομπα της Νικαράγουας"),
        ("NOK", "Κορόνα Νορβηγίας (krone)"),
        ("NPR", "Ρουπία του Νεπάλ (rupee)"),
        ("NZD", "Δολάριο Νέας Ζηλανδίας"),
        ("OMR", "Ριάλ του Ομάν"),
        ("PAB", "Μπαλμπόα Παναμά"),
        ("PEK", "ΠΕΚΕΡΟΝ"),
        ("PEN", "Σολ Περού (sol)"),
        ("PGK", "Κίνα Παπούα-Νέας Γουινέας"),
        ("PHP", "Πέσο Φιλιππίνων"),
        ("PKR", "Ρουπία του Πακιστάν (rupee)"),
        ("PLN", "Ζλότι"),
        ("PYG", "Γκουαρανί"),
        ("QAR", "Ριγιάλ του Κατάρ"),
        ("RON", "Λέου Ρουμανίας"),
        ("RUB", "Ρούβλι Ρωσίας"),
        ("RWF", "Φράγκο της Ρουάντα"),
        ("SAR", "Ριάλ Σαουδικής Αραβίας (riyal)"),
        ("SBD", "Δολάριο των Νήσων του Σολομώντα"),
        ("SCR", "Ρουπία των Σεϋχελλών (Seychellois rupee)"),
        ("SDG", "Λίρα του Σουδάν"),
        ("SEK", "Κορόνα Σουηδίας (krona)"),
        ("SGD", "Δολάριο Σιγκαπούρης"),
        ("SLL", "Λεόνε της Σιέρα Λεόνε"),
        ("SOS", "Σελίνι Σομαλίας"),
        ("SRD", "Δολάριο του Σουρινάμ"),
        ("SSP", "Λίρα Νοτίου Σουδάν"),
        ("STN", "Ντόμπρα"),
        ("SYP", "Λίρα Συρίας"),
        ("SZL", "Λιλανγκένι"),
        ("THB", "Μπαχτ"),
        ("TJS", "Σομόνι"),
        ("TMM", "Μανάτ του Τουρκμενιστάν"),
        ("TND", "Δηνάριο Τυνησίας"),
        ("TOP", "Παάνγκα"),
        ("TRY", "Τουρκική Λίρα"),
        ("TTD", "Δολάριο Τρινιντάντ και Τομπάγκο"),
        ("TZS", "Σελίνι Τανζανίας (shilling)"),
        ("UAH", "Γρίβνα Ουκρανίας"),
        ("UGX", "Σελίνι Ουγκάντας"),
        ("USD", "Δολάριο ΗΠΑ"),
        ("UYU", "Πέσο Ουρουγουάης"),
        ("UZS", "Σομ του Ουζμπεκιστάν"),
        ("VES", "Μπολίβαρ Σομπεράνο"),
        ("VND", "Ντονγκ"),
        ("VUV", "Βάτου"),
        ("WST", "Τάλα Σαμόα"),
        ("XAF", "Φράγκο CFA Κεντρικής Αφρικής"),
        ("XCD", "Δολάριο Ανατολικής Καραϊβικής"),
        ("XOF", "Φράγκο CFA Δυτικής Αφρικής"),
        ("YER", "Ριάλ Υεμένης"),
        ("ZAR", "Ραντ Νότιας Αφρικής"),
        ("ZMK", "Κουάτσα της Ζάμπιας"),
        ("ZWD", "RTGS Dollar"),
    )

    price_formats = ["#,##", "%#,##", "%##,##", "%.###,##", "%#.###,##"]

    def pricetag(self) -> str:
        return self.numerify(self.random_element(self.price_formats)) + "\N{NO-BREAK SPACE}\N{EURO SIGN}"



from .. import Provider as BaseProvider


class Provider(BaseProvider):
    # jobs parsed from a list provided by State Treasury:
    # http://www.valtiokonttori.fi/download/noname/%7BF69EA5BD-C919-49FE-8D51-91434E4B030D%7D/82158
    jobs = [
        "Agrologi",
        "Aikuiskoulutusjohtaja",
        "Aineenopettaja",
        "Ajojärjestelijä",
        "Akatemian tutkijatohtori",
        "Aktuaari",
        "Alakoulujen apulaisrehtori",
        "Alikersantti",
        "Alkoholiasiain ylitarkastaja",
        "Back office asiantuntija",
        "Ballistikko",
        "Bioanalyytikko",
        "Brand manager",
        "Budjettiassistentti",
        "Business controller",
        "Cc-yritysneuvoja",
        "Cert-fi -yksikön päällikkö",
        "Communication officer",
        "Consul",
        "Counsellor",
        "Data-analyytikko",
        "Dekaanin sihteeri",
        "Dieettikeittäjä",
        "Digitaalisen kokeen toteuttaja",
        "Diplomi-insinööri",
        "Dokumentoija",
        "Dosentti",
        "Eakr-koordinaattori",
        "Editoija",
        "Edunvalvontasihteeri",
        "Egr-ohjaaja",
        "Ekokampuskoordinaattori",
        "Elektroniikka-asentaja",
        "Elinkeinopäällikkö",
        "Elokuvakonemestari",
        "Elputeknikko",
        "Eläinlääkintöneuvos",
        "Faktori",
        "Farmakologi",
        "Fidipro-professori",
        "Filmiteknikko",
        "Financial controller",
        "Floristi",
        "Fysioterapeutti",
        "Fyysikko",
        "Gemmologi",
        "Gentax-järjestelmäasiantuntija",
        "Geofyysikko",
        "Gis-asiantuntija",
        "Gm huto pääkäyttäjä",
        "Graafikko",
        "Haastattelija",
        "Hakukoordinaattori",
        "Hallimestari",
        "Hammashoitaja",
        "Hankearkkitehti",
        "Harjaantumisopetuksen erityisluokanopettaja",
        "Havainnontarkastaja",
        "Helikopterihuoltoaliupseeri",
        "Henkikirjoittaja",
        "Johtava kuluttajaoikeusneuvoja",
        "Ict-arkkitehti",
        "Ihmisoikeuskeskuksen johtaja",
        "Iktyonomi",
        "Ilma-aluksen päällikkö",
        "Iltapäiväkerhon ohjaaja",
        "Immunologi",
        "Info-palvelupisteen hoitaja",
        "Innoittaja",
        "Jakeluvastaava",
        "Jalkaväen tarkastaja",
        "Jaoksen johtaja",
        "Jatkokoulutettava eläinlääkäri",
        "Jhs-projektipäällikkö",
        "Johdon asiantuntija",
        "Joukkoliikenneasiantuntija",
        "Julkaisu- ja markkinointisuunnittelija",
        "Junamies",
        "Juontaja",
        "Kaapeli-insinööri",
        "Kabinettisihteeri",
        "Kadettikoulun johtaja",
        "Kahvila-apulainen",
        "Kairaaja",
        "Kalabiologi",
        "Kampanjapäällikkö",
        "Kanavanhoitaja",
        "Kapellimestari",
        "Karjamestari",
        "Laadunvarmistuksen asiantuntija",
        "Laboraattori",
        "Laillisuusvalvontasihteeri",
        "Laki- ja henkilöstöasiainjohtaja",
        "Lapsiasiavaltuutettu",
        "Laskennan kehittämispäällikkö",
        "Lataamoinsinööri",
        "Lautakuntasihteeri",
        "Lavastaja",
        "Maa- ja vesirakennustyöntekijä",
        "Maisema-arkkitehti",
        "Majakkateknikko",
        "Maksatusasiantuntija",
        "Malli",
        "Mareografihoitaja",
        "Mastoteknikko",
        "Matemaatikko",
        "Media- ja kulttuurikoordinaattori",
        "Neuropsykologi",
        "Nimikkeistöpäällikkö",
        "Nosturinkuljettaja",
        "Notaari",
        "Nukutuslääkäri",
        "Numerointisihteeri",
        "Nuorempi konstaapeli",
        "Näytearkistonhoitaja",
        "Näönkäytön asiantuntija",
        "Obduktiokoordinaattori",
        "Observaattori",
        "Offset-monistaja",
        "Ohjaaja",
        "Oikaisulautakunnan puheenjohtaja",
        "Oleskelulupakäsittelijä",
        "Omistajaohjausyksikön johtaja",
        "Ompelija",
        "Opas",
        "Operaatiopäällikkö",
        "Padonhoitaja",
        "Paikallisjohtaja",
        "Pakolaiskeskuksen johtaja",
        "Palkanlaskentapäällikkö",
        "Panostaja",
        "Paperikonservaattori",
        "Parturi-kampaaja",
        "Passi- ja maahantulolupavirkailija/toimistovirkailija",
        "Pataljoonan komentaja",
        "Pedagogi",
        "Radioasentaja",
        "Rahakammion johtaja",
        "Raideliikennejohtaja",
        "Rajaeläinlääkäri",
        "Rakennemuutosjohtaja",
        "Raportoinnin asiantuntija",
        "Ratainsinööri",
        "Rauhanturvaaja",
        "Ravintohaastattelija",
        "Rehtori",
        "Saamelaisarkistonhoitaja",
        "Sadehavainnontekijä",
        "Sairaala-apulainen",
        "Saksan, englannin ja ruotsinkielen lehtori",
        "Salkunhoitaja",
        "Sanomakeskusaliupseeri",
        "Satamapäällikkö",
        "Seismologi",
        "Sektorijohtaja",
        "Selvittelijä",
        "Taajuussuunnittelija",
        "Taideamanuenssi",
        "Tallentaja",
        "Tanssija",
        "Tapahtumakoordinaattori",
        "Tarjoilija",
        "Tasa-arvoneuvos",
        "Tavaraliikennelupakäsittelijä",
        "Team finland kasvu- ja kansainvälistymiskoordinaattori",
        "Teemapäällikkö",
        "Ulkoasiainneuvos",
        "Ulosottojohtaja",
        "Ultraäänihoitaja",
        "Unix-asiantuntija",
        "Upseeri",
        "Urakonsultti",
        "Urheiluohjaaja",
        "Vaaitsija",
        "Vac-yhdyshenkilö",
        "Vahingonkorvausasiantuntija",
        "Vaihteenhoitaja",
        "Vakuustoimittaja",
        "Valaistusmestari",
        "Vammaisasiamies",
        "Vanhempi tutkijainsinööri",
        "Vapaa-ajan ohjaaja",
        "Varadekaani",
        "Www-asiantuntija",
        "Yhdenvertaisuusvaltuutettu",
        "Yhteinen tuntiopettaja",
        "Yksikkösihteeri",
        "Yleinen edunvalvoja",
        "Yliaktuaari",
        "Ylläpidon palvelupäällikkö",
        "Yläasteen rehtori",
        "Ympärintönsuojeluyksikön päällikkö",
        "Yrittäjyysneuvoja",
        "Yva-koordinaattori",
    ]



from .. import Provider as ColorProvider


class Provider(ColorProvider):
    """Implement color provider for ``cs_CZ`` locale."""

    safe_colors = (
        "černá",
        "kaštanová",
        "zelená",
        "námořnická",
        "olivová",
        "fialová",
        "zelenomodrá",
        "limetková",
        "modrá",
        "stříbrná",
        "šedá",
        "žlutá",
        "fuchsiová",
        "aquamarinová",
        "bílá",
    )



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{last_name}}",
    )

    company_suffixes = (
        "АД",
        "AD",
        "ADSITz",
        "АДСИЦ",
        "EAD",
        "ЕАД",
        "EOOD",
        "ЕООД",
        "ET",
        "ET",
        "OOD",
        "ООД",
        "KD",
        "КД",
        "KDA",
        "КДА",
        "SD",
        "СД",
    )



import re
import string

from math import ceil
from string import ascii_uppercase
from typing import Dict, Optional

from .. import BaseProvider

localized = True
default_locale = "en_GB"


class Provider(BaseProvider):
    """Implement default bank provider for Faker.

    .. important::
       Bank codes, account numbers, and other ID's generated by this provider
       are only valid in form, i.e. they conform to some standard/format, are
       of the expected lengths, and have valid checksums (where applicable).
       Results generated that turn out to be valid in real life are purely
       coincidental.

    Sources:

    - https://en.wikipedia.org/wiki/International_Bank_Account_Number
    - https://www.theswiftcodes.com/swift-code-checker/
    """

    ALPHA: Dict[str, str] = {c: str(ord(c) % 55) for c in string.ascii_uppercase}
    bban_format: str = "????#############"
    country_code: str = "GB"

    def aba(self) -> str:
        """Generate an ABA routing transit number."""
        fed_num = self.random_int(min=1, max=12)
        rand = self.numerify("######")
        aba = f"{fed_num:02}{rand}"

        # calculate check digit
        d = [int(n) for n in aba]
        chk_digit = 3 * (d[0] + d[3] + d[6]) + 7 * (d[1] + d[4] + d[7]) + d[2] + d[5]
        chk_digit = ceil(chk_digit / 10) * 10 - chk_digit

        return f"{aba}{chk_digit}"

    def bank_country(self) -> str:
        """Generate the bank provider's ISO 3166-1 alpha-2 country code."""
        return self.country_code

    def bank(self) -> str:
        """Generate a bank name."""
        if not hasattr(self, "banks"):
            raise AttributeError(
                f"The {self.__class__.__name__} provider does not have a 'banks' "
                "attribute. Consider contributing to the project and "
                " adding a 'banks' tuple to enable bank name generation."
            )
        return self.random_element(self.banks)

    def bban(self) -> str:
        """Generate a Basic Bank Account Number (BBAN)."""
        temp = re.sub(r"\?", lambda x: self.random_element(ascii_uppercase), self.bban_format)
        return self.numerify(temp)

    def iban(self) -> str:
        """Generate an International Bank Account Number (IBAN)."""
        bban = self.bban()

        check = bban + self.country_code + "00"
        check_ = int("".join(self.ALPHA.get(c, c) for c in check))
        check_ = 98 - (check_ % 97)
        check = str(check_).zfill(2)

        return self.country_code + check + bban

    def swift8(self, use_dataset: bool = False) -> str:
        """Generate an 8-digit SWIFT code.

        This method uses |swift| under the hood with the ``length`` argument set
        to ``8`` and with the ``primary`` argument omitted. All 8-digit SWIFT
        codes already refer to the primary branch/office.

        :sample:
        :sample: use_dataset=True
        """
        return self.swift(length=8, use_dataset=use_dataset)

    def swift11(self, primary: bool = False, use_dataset: bool = False) -> str:
        """Generate an 11-digit SWIFT code.

        This method uses |swift| under the hood with the ``length`` argument set
        to ``11``. If ``primary`` is set to ``True``, the SWIFT code will always
        end with ``'XXX'``. All 11-digit SWIFT codes use this convention to
        refer to the primary branch/office.

        :sample:
        :sample: use_dataset=True
        """
        return self.swift(length=11, primary=primary, use_dataset=use_dataset)

    def swift(
        self,
        length: Optional[int] = None,
        primary: bool = False,
        use_dataset: bool = False,
    ) -> str:
        """Generate a SWIFT code.

        SWIFT codes, reading from left to right, are composed of a 4 alphabet
        character bank code, a 2 alphabet character country code, a 2
        alphanumeric location code, and an optional 3 alphanumeric branch code.
        This means SWIFT codes can only have 8 or 11 characters, so the value of
        ``length`` can only be ``None`` or the integers ``8`` or ``11``. If the
        value is ``None``, then a value of ``8`` or ``11`` will randomly be
        assigned.

        Because all 8-digit SWIFT codes already refer to the primary branch or
        office, the ``primary`` argument only has an effect if the value of
        ``length`` is ``11``. If ``primary`` is ``True`` and ``length`` is
        ``11``, the 11-digit SWIFT codes generated will always end in ``'XXX'``
        to denote that they belong to primary branches/offices.

        For extra authenticity, localized providers may opt to include SWIFT
        bank codes, location codes, and branch codes used in their respective
        locales. If ``use_dataset`` is ``True``, this method will generate SWIFT
        codes based on those locale-specific codes if included. If those codes
        were not included, then it will behave as if ``use_dataset`` were
        ``False``, and in that mode, all those codes will just be randomly
        generated as per the specification.

        :sample:
        :sample: length=8
        :sample: length=8, use_dataset=True
        :sample: length=11
        :sample: length=11, primary=True
        :sample: length=11, use_dataset=True
        :sample: length=11, primary=True, use_dataset=True
        """
        if length is None:
            length = self.random_element((8, 11))
        if length not in (8, 11):
            raise AssertionError("length can only be 8 or 11")

        if use_dataset and hasattr(self, "swift_bank_codes"):
            bank_code: str = self.random_element(self.swift_bank_codes)  # type: ignore[attr-defined]
        else:
            bank_code = self.lexify("????", letters=string.ascii_uppercase)

        if use_dataset and hasattr(self, "swift_location_codes"):
            location_code: str = self.random_element(self.swift_location_codes)  # type: ignore[attr-defined]
        else:
            location_code = self.lexify("??", letters=string.ascii_uppercase + string.digits)

        if length == 8:
            return bank_code + self.country_code + location_code

        if primary:
            branch_code = "XXX"
        elif use_dataset and hasattr(self, "swift_branch_codes"):
            branch_code = self.random_element(self.swift_branch_codes)  # type: ignore[attr-defined]
        else:
            branch_code = self.lexify("???", letters=string.ascii_uppercase + string.digits)

        return bank_code + self.country_code + location_code + branch_code



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    # Source: https://vi.wikipedia.org/wiki/%C4%90%E1%BB%8Bnh_d%E1%BA%A1ng_ng%C3%A0y_v%C3%A0_gi%E1%BB%9D_%E1%BB%9F_Vi%E1%BB%87t_Nam  # NOQA
    DAY_NAMES = {
        "0": "Chủ Nhật",
        "1": "Thứ Hai",
        "2": "Thứ Ba",
        "3": "Thứ Tư",
        "4": "Thứ Năm",
        "5": "Thứ Sáu",
        "6": "Thứ Bảy",
    }

    MONTH_NAMES = {
        "01": "Tháng Một",
        "02": "Tháng Hai",
        "03": "Tháng Ba",
        "04": "Tháng Tư",
        "05": "Tháng Năm",
        "06": "Tháng Sáu",
        "07": "Tháng Bảy",
        "08": "Tháng Tám",
        "09": "Tháng Chín",
        "10": "Tháng Mười",
        "11": "Tháng Mười Một",
        "12": "Tháng Mười Hai",
    }

    def day_of_week(self):
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        return self.MONTH_NAMES[month]



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    """
    Provider for company names for ko_KR locale
    """

    formats = (
        "{{company_suffix}} {{company_name_word}}{{brand_suffix}}",
        "{{company_suffix}} {{company_name_word}}{{company_name_word}}{{brand_suffix}}",
        "{{company_suffix}} {{company_name_word}}",
    )

    catch_phrase_words = (
        (
            "적응된",
            "숙련된",
            "자동화된",
            "안정적인",
            "비즈니스 중점적",
            "중심이",
            "복제된",
            "효율적인",
            "설정 가능한",
            "크로스 그룹",
            "크로스 플랫폼",
            "사용자 중심의",
            "조절 가능한",
            "디지털화된",
            "출판된",
            "다양한",
            "낮은",
            "강화된",
            "인체 공학적인",
            "특별한",
            "확장된",
            "확대된",
            "1:1",
            "최전방",
            "완벽히 설정된",
            "함수 기반의",
            "미래가 보장된",
            "관리된",
            "모니터링되는",
            "멀티 채널",
            "다중 주파수",
            "멀티 레이어",
            "조직화된",
            "객체 기반의",
            "공개 아키텍쳐",
            "오픈소스",
            "최적화된",
            "선택적",
            "유기농",
            "수익에 중점을 둔",
            "프로그래밍 가능한",
            "진보적인",
            "공개 키",
            "품질 중심의",
            "반동적인",
            "재정렬",
            "줄어든",
            "리버스 엔지니어링된",
            "올바른 사이즈의",
            "강력한",
            "원활한",
            "안전한",
            "자가 이용 가능한",
            "공유 가능한",
            "독보적인",
            "무결점의",
            "변경 가능한",
            "동기화",
            "융합력있는",
            "융합된",
            "단체 기반의",
            "총",
            "트리플 버퍼",
            "다용도",
            "더 커진",
            "업그레이드 가능한",
            "더 작아진",
            "유저 친화적",
            "가상",
            "비전 있는",
        ),
        (
            "24시간",
            "24/7",
            "3세대",
            "4세대",
            "5세대",
            "6세대",
            "작동",
            "분석중인",
            "비대칭",
            "비동기",
            "고도 기반",
            "백그라운드",
            "주파수 탐지 가능",
            "요약",
            "클라이언트 단",
            "클라이언트-서버",
            "밀착",
            "결합된",
            "합성물",
            "상황에 맞는",
            "문맥 기반",
            "컨텐츠 기반",
            "헌신적",
            "교훈적",
            "방향",
            "분리된",
            "다이나믹",
            "환경 친화적",
            "실행",
            "취약점",
            "스며든",
            "수요 중심",
            "장거리",
            "글로벌",
            "그리드 가능",
            "휴리스틱",
            "고단계",
            "분리형",
            "인간자원",
            "하이브리드",
            "선구적",
            "로컬",
            "물류",
            "최대화",
            "결정",
            "휴대형",
            "모듈형",
            "멀티미디어",
            "다중 상태",
            "멀티 태스킹",
            "국가적",
            "범국가적",
            "중립형",
            "다음 세대",
            "객체 지향적",
            "필수",
            "최적화된",
            "근본적",
            "실시간",
            "역수",
            "지역적",
            "확장",
            "보조",
            "해답 기반",
            "안정적",
            "정적",
            "가치추가",
            "웹 사용 가능",
            "잘 모듈화된",
            "무관리",
            "무해한",
            "무관용",
        ),
        (
            "능력",
            "접근",
            "어댑터",
            "알고리즘",
            "연합",
            "분석",
            "어플리케이션",
            "접근",
            "아키텍쳐",
            "아카이브",
            "인공지능",
            "배열",
            "태도",
            "벤치마크",
            "예산 관리",
            "환경",
            "생산 능력",
            "도전",
            "회로",
            "융합",
            "컨셉",
            "축적",
            "우연성",
            "코어",
            "고객 만족",
            "데이터베이스",
            "정의",
            "에뮬레이션",
            "인코딩",
            "암호화",
            "엑스트라넷",
            "펌웨어",
            "유연성",
            "예보",
            "프레임",
            "프레임워크",
            "함수",
            "그래픽 인터페이스",
            "그룹웨어",
            "GUI",
            "하드웨어",
            "안내 창구",
            "계층",
            "허브",
            "미디어 정보",
            "환경",
            "설치과정",
            "인터페이스",
            "인트라넷",
            "지식 기반",
            "LAN",
            "미들웨어",
            "마이그레이션",
            "모델",
            "관리자",
            "모니터링",
            "공개 시스템",
            "패러다임",
            "정책",
            "포탈",
            "제품",
            "프로젝트",
            "프로토콜",
            "서비스 창구",
            "소프트웨어",
            "솔루션",
            "보안구역",
            "전략",
            "구조체",
            "성공",
            "지원",
            "시너지",
            "엔진",
            "표준",
            "시간화",
            "공구",
            "웹 사이트",
        ),
    )

    bsWords = (
        (
            "다용도의",
            "통합된",
            "간소화된",
            "최적화된",
            "진화된",
            "변화된",
            "포용적인",
            "사용 가능한",
            "웅장한",
            "재평가된",
            "재발명된",
            "구조적인",
            "강화된",
            "장려하는",
            "변화무쌍한",
            "자율적인",
            "선구적인",
            "화폐화된",
            "전략적인",
            "발전하는",
            "합성",
            "배송",
            "혼합된",
            "최대화된",
            "벤치마킹된",
            "신속한",
            "깨끗한",
            "시각적인",
            "창의적인",
            "큰",
            "폭발하는",
            "확장된",
            "엔지니어",
            "혁명적인",
            "제작된",
            "취약점의",
            "배열적인",
            "문화적인",
        ),
        (
            "온라인 쇼핑",
            "가치 상승",
            "선구적",
            "철벽",
            "혁명적",
            "가변",
            "창조적",
            "직감",
            "전략적",
            "전자 비즈니스",
            "끈끈한",
            "1:1",
            "24/7",
            "글로벌",
            "B2B",
            "B2C",
            "고운",
            "가상",
            "바이러스성",
            "다이나믹",
            "24/365",
            "고사양",
            "킬러",
            "자기장",
            "최첨단",
            "닷컴",
            "섹시",
            "백 엔드",
            "실시간",
            "효율적",
            "프론트 엔드",
            "무결점",
            "확장",
            "턴키",
            "세계급",
            "오픈 소스",
            "크로스 플랫폼",
            "크로스 미디어",
            "엔터프라이즈",
            "통합",
            "강렬한",
            "무선",
            "투명",
            "다음 세대",
            "날카로운",
            "창의적",
            "반투명",
            "유비쿼터스",
            "플러그 앤 플레이",
            "융합",
            "강력한",
            "강렬한",
            "부자",
        ),
        (
            "시너지",
            "패러다임",
            "마케팅",
            "파트너쉽",
            "인프라",
            "플랫폼",
            "채널",
            "커뮤니티",
            "솔루션",
            "전자 서비스",
            "포탈",
            "기술",
            "컨텐츠",
            "생산라인",
            "관계",
            "아키텍쳐",
            "인터페이스",
            "전자시장",
            "전자화폐",
            "시스템",
            "주파수",
            "모델",
            "어플리케이션",
            "사용자들",
            "스키마",
            "네트웍스",
            "앱",
            "매트릭스",
            "전자 비즈니스",
            "경험",
            "웹서비스",
            "방법론",
        ),
    )

    company_suffixes = ("(주)", "주식회사", "(유)", "유한회사")

    company_name_words = (
        "가람",
        "가야",
        "가온",
        "겨레",
        "고구려",
        "고려",
        "국민",
        "글로벌",
        "글로벌",
        "나루",
        "네오",
        "넥스트",
        "다올",
        "라온",
        "마루",
        "마음",
        "모두",
        "미래",
        "발해",
        "백제",
        "보람",
        "브레인",
        "비전",
        "스타",
        "시너지",
        "신라",
        "씨앤씨",
        "아름",
        "에코",
        "우리",
        "원더",
        "월드",
        "윈드",
        "유니온",
        "이노",
        "인포",
        "제나",
        "조선",
        "종합",
        "중앙",
        "첨단",
        "코리아",
        "코어",
        "푸른",
        "하나",
        "한가람",
        "한강",
        "한빛",
    )

    brand_suffixes = (
        "개발",
        "개발공사",
        "그룹",
        "금고",
        "기술",
        "기획",
        "네트워크",
        "네트웍스",
        "랩스",
        "바이오",
        "반도체",
        "보안",
        "뷰티",
        "상사",
        "센터",
        "소프트",
        "솔루션",
        "시스템",
        "시스템즈",
        "신문",
        "에너지",
        "에이아이",
        "엔지니어링",
        "연구소",
        "유통",
        "은행",
        "자동차",
        "전자",
        "정보통신",
        "제조",
        "출판",
        "코스메틱",
        "테크",
        "플랫폼",
        "항공",
    )

    def company_name_word(self) -> str:
        return self.random_element(self.company_name_words)

    def brand_suffix(self) -> str:
        return self.random_element(self.brand_suffixes)



from collections import OrderedDict

from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats_female = OrderedDict(
        (
            ("{{first_name_female}} {{last_name_female}}", 0.97),
            ("{{prefix_female}} {{first_name_female}} {{last_name_female}}", 0.015),
            ("{{first_name_female}} {{last_name_female}} {{suffix}}", 0.02),
            (
                "{{prefix_female}} {{first_name_female}} {{last_name_female}} {{suffix}}",
                0.005,
            ),
        )
    )

    formats_male = OrderedDict(
        (
            ("{{first_name_male}} {{last_name_male}}", 0.97),
            ("{{prefix_male}} {{first_name_male}} {{last_name_male}}", 0.015),
            ("{{first_name_male}} {{last_name_male}} {{suffix}}", 0.02),
            (
                "{{prefix_male}} {{first_name_male}} {{last_name_male}} {{suffix}}",
                0.005,
            ),
        )
    )

    formats = formats_male.copy()
    formats.update(formats_female)

    # Names from
    # https://cs.wikipedia.org/wiki/Jmeniny_v_%C4%8Cesku

    first_names_male = (
        "Adam",
        "Albert",
        "Alexander",
        "Alexandr",
        "Aleš",
        "Alois",
        "Antonín",
        "Arnošt",
        "Artur",
        "Bedřich",
        "Blahoslav",
        "Bohumil",
        "Bohumír",
        "Bohuslav",
        "Boleslav",
        "Bořivoj",
        "Břetislav",
        "Ctibor",
        "Ctirad",
        "Dalibor",
        "Daniel",
        "David",
        "Denis",
        "Dobroslav",
        "Dominik",
        "Drahoslav",
        "Dušan",
        "Eduard",
        "Emil",
        "Erik",
        "Ferdinand",
        "Felix",
        "Filip",
        "František",
        "Horymír",
        "Hubert",
        "Hynek",
        "Ignác",
        "Igor",
        "Ivan",
        "Ivo",
        "Jakub",
        "Jan",
        "Jaromír",
        "Jaroslav",
        "Jindřich",
        "Jiří",
        "Jonáš",
        "Josef",
        "Jozef",
        "Ján",
        "Kamil",
        "Karel",
        "Klement",
        "Kryštof",
        "Ladislav",
        "Leoš",
        "Libor",
        "Lubomír",
        "Luboš",
        "Ludvík",
        "Luděk",
        "Lukáš",
        "Lumír",
        "Marcel",
        "Marek",
        "Marian",
        "Martin",
        "Matouš",
        "Matyáš",
        "Matěj",
        "Michael",
        "Michal",
        "Mikuláš",
        "Milan",
        "Miloslav",
        "Miloš",
        "Miroslav",
        "Mojmír",
        "Norbert",
        "Oldřich",
        "Ondřej",
        "Otakar",
        "Oto",
        "Patrik",
        "Pavel",
        "Peter",
        "Petr",
        "Přemysl",
        "Radek",
        "Radim",
        "Radomír",
        "Radoslav",
        "Radovan",
        "René",
        "Richard",
        "Robert",
        "Robin",
        "Roman",
        "Rostislav",
        "Rudolf",
        "Samuel",
        "Stanislav",
        "Slavomír",
        "Svatopluk",
        "Svatoslav",
        "Šimon",
        "Tadeáš",
        "Teodor",
        "Tomáš",
        "Vasyl",
        "Viktor",
        "Vilém",
        "Vladimír",
        "Vladislav",
        "Vlasta",
        "Vlastimil",
        "Vojtěch",
        "Vratislav",
        "Václav",
        "Vít",
        "Vítězslav",
        "Zbyněk",
        "Zdeněk",
        "Zikmund",
        "Šimon",
        "Štefan",
        "Štěpán",
    )

    # Names from
    # https://cs.wikipedia.org/wiki/Jmeniny_v_%C4%8Cesku

    first_names_female = (
        "Adéla",
        "Agáta",
        "Alena",
        "Alexandra",
        "Alice",
        "Alžběta",
        "Anastázie",
        "Anděla",
        "Andrea",
        "Aneta",
        "Anežka",
        "Anna",
        "Apolena",
        "Barbora",
        "Blanka",
        "Blažena",
        "Bohumila",
        "Božena",
        "Dagmar",
        "Dana",
        "Daniela",
        "Danuše",
        "Denisa",
        "Dita",
        "Dominika",
        "Dorota",
        "Drahomíra",
        "Drahoslava",
        "Edita",
        "Elena",
        "Eliška",
        "Ema",
        "Emilie",
        "Erika",
        "Ester",
        "Eva",
        "Evelína",
        "Františka",
        "Gabriela",
        "Hana",
        "Helena",
        "Hedvika",
        "Ilona",
        "Irena",
        "Iva",
        "Ivana",
        "Iveta",
        "Ivona",
        "Jana",
        "Jarmila",
        "Jaroslava",
        "Jindřiška",
        "Jitka",
        "Jiřina",
        "Johana",
        "Jolana",
        "Judita",
        "Julie",
        "Kamila",
        "Karolína",
        "Kateřina",
        "Klaudie",
        "Klára",
        "Kristina",
        "Kristýna",
        "Květa",
        "Květoslava",
        "Lada",
        "Ladislava",
        "Lenka",
        "Leona",
        "Libuše",
        "Linda",
        "Lucie",
        "Ludmila",
        "Lýdie",
        "Magdalena",
        "Magdaléna",
        "Mahulena",
        "Marcela",
        "Marie",
        "Markéta",
        "Marta",
        "Martina",
        "Michaela",
        "Milada",
        "Milena",
        "Miloslava",
        "Miluše",
        "Miroslava",
        "Monika",
        "Mária",
        "Naděžda",
        "Natálie",
        "Nela",
        "Nina",
        "Nikol",
        "Nikola",
        "Nora",
        "Olivie",
        "Olga",
        "Otýlie",
        "Patricie",
        "Pavla",
        "Pavlína",
        "Petra",
        "Radka",
        "Renata",
        "Renáta",
        "Romana",
        "Růžena",
        "Sabina",
        "Simona",
        "Silvie",
        "Slavěna",
        "Soňa",
        "Stanislava",
        "Světlana",
        "Sára",
        "Šárka",
        "Štěpánka",
        "Tereza",
        "Vanda",
        "Vendula",
        "Veronika",
        "Věra",
        "Viktorie",
        "Vilma",
        "Vladimíra",
        "Vlasta",
        "Věra",
        "Zdenka",
        "Zdeňka",
        "Zora",
        "Zuzana",
        "Štěpánka",
        "Šárka",
        "Zdislava",
        "Žaneta",
        "Žofie",
    )

    first_names = first_names_male + first_names_female

    # Last names from
    # https://cs.wikipedia.org/wiki/Seznam_nej%C4%8Detn%C4%9Bj%C5%A1%C3%ADch_p%C5%99%C3%ADjmen%C3%AD_v_%C4%8Cesku

    last_names_male = (
        "Bárta",
        "Bartoš",
        "Bednář",
        "Beneš",
        "Beran",
        "Beránek",
        "Bílek",
        "Bláha",
        "Blažek",
        "Brož",
        "Bureš",
        "Čech",
        "Čermák",
        "Černý",
        "Doležal",
        "Dostál",
        "Dušek",
        "Dvořák",
        "Fiala",
        "Fišer",
        "Hájek",
        "Havel",
        "Havlíček",
        "Holub",
        "Horáček",
        "Horák",
        "Horváth",
        "Hrubý",
        "Hruška",
        "Janda",
        "Jaroš",
        "Jelínek",
        "Ježek",
        "Kadlec",
        "Kašpar",
        "Kolář",
        "Konečný",
        "Kopecký",
        "Kovář",
        "Král",
        "Kratochvíl",
        "Kraus",
        "Kříž",
        "Kubíček",
        "Kučera",
        "Liška",
        "Mach",
        "Macháček",
        "Malý",
        "Marek",
        "Mareš",
        "Mašek",
        "Matějka",
        "Matoušek",
        "Moravec",
        "Müller",
        "Musil",
        "Navrátil",
        "Němec",
        "Němeček",
        "Novák",
        "Novotný",
        "Pavlíček",
        "Pavlík",
        "Pokorný",
        "Polák",
        "Pospíšil",
        "Procházka",
        "Prokop",
        "Růžička",
        "Říha",
        "Sedláček",
        "Sedlák",
        "Slavík",
        "Soukup",
        "Staněk",
        "Stejskal",
        "Strnad",
        "Svoboda",
        "Sýkora",
        "Ševčík",
        "Šimek",
        "Šmíd",
        "Šťastný",
        "Štěpánek",
        "Švec",
        "Tesař",
        "Tichý",
        "Toman",
        "Tůma",
        "Urban",
        "Vacek",
        "Valenta",
        "Vaněk",
        "Vávra",
        "Veselý",
        "Vítek",
        "Vlček",
        "Zeman",
        "Žák",
    )

    # Last names from
    # https://cs.wikipedia.org/wiki/Seznam_nej%C4%8Detn%C4%9Bj%C5%A1%C3%ADch_p%C5%99%C3%ADjmen%C3%AD_v_%C4%8Cesku

    last_names_female = (
        "Bartošová",
        "Bártová",
        "Bednářová",
        "Benešová",
        "Beránková",
        "Beranová",
        "Bílková",
        "Bláhová",
        "Blažková",
        "Brožová",
        "Burešová",
        "Čechová",
        "Čermáková",
        "Černá",
        "Doležalová",
        "Dostálová",
        "Dušková",
        "Dvořáková",
        "Fialová",
        "Fišerová",
        "Hájková",
        "Havlíčková",
        "Holubová",
        "Horáčková",
        "Horáková",
        "Horváthová",
        "Hrubá",
        "Hrušková",
        "Jandová",
        "Janečková",
        "Jarošová",
        "Jelínková",
        "Ježková",
        "Kadlecová",
        "Kašparová",
        "Kolářová",
        "Konečná",
        "Kopecká",
        "Kovářová",
        "Králová",
        "Kratochvílová",
        "Krausová",
        "Krejčová",
        "Křížová",
        "Kubíčková",
        "Kučerová",
        "Lišková",
        "Macháčková",
        "Machová",
        "Malá",
        "Marešová",
        "Marková",
        "Mašková",
        "Matějková",
        "Matoušková",
        "Moravcová",
        "Müllerová",
        "Musilová",
        "Navrátilová",
        "Němcová",
        "Němečková",
        "Nováková",
        "Novotná",
        "Pavlíková",
        "Pešková",
        "Petrová",
        "Pokorná",
        "Poláková",
        "Pospíšilová",
        "Procházková",
        "Růžičková",
        "Říhová",
        "Sedláčková",
        "Sedláková",
        "Slavíková",
        "Soukupová",
        "Staňková",
        "Stejskalová",
        "Strnadová",
        "Svobodová",
        "Sýkorová",
        "Ševčíková",
        "Šimková",
        "Šmídová",
        "Šťastná",
        "Štěpánková",
        "Švecová",
        "Tichá",
        "Tomanová",
        "Tůmová",
        "Urbanová",
        "Vacková",
        "Valentová",
        "Vaňková",
        "Vávrová",
        "Veselá",
        "Vítková",
        "Vlčková",
        "Zemanová",
        "Žáková",
    )

    last_names = last_names_male + last_names_female

    # Degrees from
    # https://cs.wikipedia.org/wiki/Akademick%C3%BD_titul
    # https://eprehledy.cz/ceske_tituly.php

    degrees = ("JUDr.", "Ing.", "Bc.", "Mgr.", "MUDr.", "RNDr.", "Ing. arch.", "MVDr.", "PhDr.")

    prefixes_male = ("pan",) + degrees

    prefixes_female = ("paní", "slečna") + degrees

    suffixes = (
        "CSc.",
        "DiS.",
        "Ph.D.",
        "Th.D.",
        "DSc.",
    )



"""This module provides address-related functionalities for Vietnamese addresses."""

from collections import OrderedDict
from typing import Optional, Tuple

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    """Provider for generating Vietnamese addresses.
    Sources:

    # https://vi.wikipedia.org/wiki/B%E1%BA%A3n_m%E1%BA%ABu:K%C3%BD_hi%E1%BB%87u_quy_%C6%B0%E1%BB%9Bc_c%C3%A1c_t%E1%BB%89nh_th%C3%A0nh_Vi%E1%BB%87t_Nam
    """

    city_prefixes = ("Thành phố", "Quận", "Huyện", "Thị xã")

    city_suffixes = (
        "Thành phố",
        "Quận",
        "Huyện",
        "Thị xã",
        "Xã",
        "Phường",
    )

    building_number_formats = ("###", "##", "#")

    street_suffixes = (
        "Đường",
        "Ngõ",
        "Hẻm",
        "Làng",
        "Khu",
        "Tổ",
        "Số",
        "Dãy",
    )

    postcode_formats = ("######",)

    provinces = (
        "An Giang",
        "Bà Rịa – Vũng Tàu",
        "Bạc Liêu",
        "Bắc Kạn",
        "Bắc Giang",
        "Bắc Ninh",
        "Bến Tre",
        "Bình Dương",
        "Bình Định",
        "Bình Phước",
        "Bình Thuận",
        "Cà Mau",
        "Cao Bằng",
        "Cần Thơ",
        "Đà Nẵng",
        "Đắk Lắk",
        "Đắk Nông",
        "Điện Biên",
        "Đồng Nai",
        "Đồng Tháp",
        "Gia Lai",
        "Hà Giang",
        "Hà Nam",
        "Hà Nội",
        "Hà Tĩnh",
        "Hải Dương",
        "Hải Phòng",
        "Hậu Giang",
        "Hòa Bình",
        "Thành phố Hồ Chí Minh",
        "Hưng Yên",
        "Khánh Hòa",
        "Kiên Giang",
        "Kon Tum",
        "Lai Châu",
        "Lạng Sơn",
        "Lào Cai",
        "Lâm Đồng",
        "Long An",
        "Nam Định",
        "Nghệ An",
        "Ninh Bình",
        "Ninh Thuận",
        "Phú Thọ",
        "Phú Yên",
        "Quảng Bình",
        "Quảng Nam",
        "Quảng Ngãi",
        "Quảng Ninh",
        "Quảng Trị",
        "Sóc Trăng",
        "Sơn La",
        "Tây Ninh",
        "Thái Bình",
        "Thái Nguyên",
        "Thanh Hóa",
        "Thừa Thiên Huế",
        "Tiền Giang",
        "Trà Vinh",
        "Tuyên Quang",
        "Vĩnh Long",
        "Vĩnh Phúc",
        "Yên Bái",
    )

    provinces_abbr = (
        "AG",
        "BV",
        "BL",
        "BK",
        "BG",
        "BN",
        "BT",
        "BD",
        "BĐ",
        "BP",
        "BTh",
        "CM",
        "CB",
        "CT",
        "ĐNa",
        "ĐL",
        "ĐNo",
        "ĐB",
        "ĐN",
        "ĐT",
        "GL",
        "HG",
        "HNa",
        "HN",
        "HT",
        "HD",
        "HP",
        "HGi",
        "HB",
        "SG",
        "HY",
        "KH",
        "KG",
        "KT",
        "LC",
        "LS",
        "LCa",
        "LĐ",
        "LA",
        "NĐ",
        "NA",
        "NB",
        "NT",
        "PT",
        "PY",
        "QB",
        "QNa",
        "QNg",
        "QN",
        "QT",
        "ST",
        "SL",
        "TN",
        "TB",
        "TNg",
        "TH",
        "TTH",
        "TG",
        "TV",
        "TQ",
        "VL",
        "VP",
        "YB",
    )

    provinces_postcode = {
        "AG": (88000, 88999),
        "BV": (79000, 79999),
        "BL": (96000, 96999),
        "BK": (26000, 26999),
        "BG": (23000, 23999),
        "BN": (22000, 22999),
        "BT": (93000, 93999),
        "BD": (82000, 82999),
        "BĐ": (59000, 59999),
        "BP": (83000, 83999),
        "BTh": (80000, 80999),
        "CM": (97000, 97999),
        "CB": (27000, 27999),
        "CT": (92000, 92999),
        "ĐNa": (55000, 55999),
        "ĐL": (63000, 63999),
        "ĐNo": (64000, 64999),
        "ĐB": (38000, 38999),
        "ĐN": (81000, 81999),
        "ĐT": (87000, 87999),
        "GL": (60000, 60999),
        "HG": (31000, 31999),
        "HNa": (40000, 40999),
        "HN": (10000, 15999),
        "HT": (48000, 48999),
        "HD": (17000, 17999),
        "HP": (18000, 18999),
        "HGi": (91000, 91999),
        "HB": (35000, 35999),
        "SG": (70000, 76999),
        "HY": (16000, 16999),
        "KH": (65000, 65999),
        "KG": (92000, 92999),
        "KT": (58000, 58999),
        "LC": (39000, 39999),
        "LS": (24000, 24999),
        "LCa": (33000, 33999),
        "LĐ": (67000, 67999),
        "LA": (85000, 85999),
        "NĐ": (42000, 42999),
        "NA": (46000, 47999),
        "NB": (43000, 43999),
        "NT": (66000, 66999),
        "PT": (29000, 29999),
        "PY": (62000, 62999),
        "QB": (51000, 51999),
        "QNa": (56000, 56999),
        "QNg": (57000, 57999),
        "QN": (20000, 20999),
        "QT": (52000, 52999),
        "ST": (95000, 95999),
        "SL": (36000, 36999),
        "TN": (84000, 84999),
        "TB": (41000, 41999),
        "TNg": (25000, 25999),
        "TH": (44000, 45999),
        "TTH": (53000, 53999),
        "TG": (86000, 86999),
        "TV": (94000, 94999),
        "TQ": (30000, 30999),
        "VL": (89000, 89999),
        "VP": (28000, 28999),
        "YB": (32000, 32999),
    }

    address_formats = OrderedDict(
        (
            ("{{street_address}}\n{{city}}, {{postcode}}", 25.0),
            ("{{city}}\n{{street_address}}, {{postcode}}", 1.0),
        )
    )

    city_formats = (
        "{{city_prefix}} {{first_name}}{{city_suffix}}",
        "{{first_name}}{{city_suffix}}",
    )

    street_name_formats = (
        "{{first_name}} {{street_suffix}}",
        "{{last_name}} {{street_suffix}}",
    )

    street_address_formats = ("{{building_number}} {{street_name}}",)

    def city_prefix(self) -> str:
        """Returns a random city prefix."""
        return self.random_element(self.city_prefixes)

    def administrative_unit(self) -> str:
        """Returns a random administrative unit (province)."""
        return self.random_element(self.provinces)

    state = administrative_unit

    def state_abbr(self) -> str:
        """
        Returns a random two-letter abbreviation for Vietnamese provinces.

        """
        abbreviations: Tuple[str, ...] = self.provinces_abbr
        return self.random_element(abbreviations)

    def postcode(self) -> str:
        """Returns a random postcode."""
        return f"{self.generator.random.randint(100000, 999999):06d}"

    def postcode_in_state(self, state_abbr: Optional[str] = None) -> str:
        """
        Returns a random postcode within the provided province abbreviation.

        :param state_abbr: A province abbreviation.
        :returns: A random postcode within the provided province abbreviation.
        """
        if state_abbr is None:
            state_abbr = self.random_element(self.provinces_abbr)

        if state_abbr in self.provinces_abbr:
            postcode = str(
                self.generator.random.randint(
                    self.provinces_postcode[state_abbr][0], self.provinces_postcode[state_abbr][1]
                )
            )

            # zero left pad up until desired length (length is 6)
            target_postcode_len = 6
            current_postcode_len = len(postcode)
            if current_postcode_len < target_postcode_len:
                pad = target_postcode_len - current_postcode_len
                postcode = f"{'0' * pad}{postcode}"

            return postcode

        raise ValueError("Province Abbreviation not found in list")



from typing import Tuple

from .. import Provider as AddressProvider


class Provider(AddressProvider):
    """Address provider for fr_DZ locale."""

    # Source: https://fr.wikipedia.org/wiki/Wilayas_d%27Alg%C3%A9rie
    wilayas: Tuple[str, ...] = (
        "Adrar",
        "Chlef",
        "Laghouat",
        "Oum El Bouaghi",
        "Batna",
        "Béjaïa",
        "Biskra",
        "Béchar",
        "Blida",
        "Bouira",
        "Tamanrasset",
        "Tébessa",
        "Tlemcen",
        "Tiaret",
        "Tizi Ouzou",
        "Alger",
        "Djelfa",
        "Jijel",
        "Sétif",
        "Saïda",
        "Skikda",
        "Sidi Bel Abbès",
        "Annaba",
        "Guelma",
        "Constantine",
        "Médéa",
        "Mostaganem",
        "M'Sila",
        "Mascara",
        "Ouargla",
        "Oran",
        "El Bayadh",
        "Illizi",
        "Bordj Bou Arreridj",
        "Boumerdès",
        "El Tarf",
        "Tindouf",
        "Tissemsilt",
        "El Oued",
        "Khenchela",
        "Souk Ahras",
        "Tipaza",
        "Mila",
        "Aïn Defla",
        "Naâma",
        "Aïn Témouchent",
        "Ghardaïa",
        "Relizane",
        "Timimoun",
        "Bordj Badji Mokhtar",
        "Ouled Djellal",
        "Béni Abbès",
        "In Salah",
        "In Guezzam",
        "Touggourt",
        "Djanet",
        "El Meghaier",
        "El Menia",
    )

    # Source: https://github.com/othmanus/algeria-cities
    cities: Tuple[str, ...] = (
        # Wilaya 01 - Adrar
        "Adrar",
        "Reggane",
        "Aoulef",
        "Timimoun",
        # Wilaya 02 - Chlef
        "Chlef",
        "Ténès",
        "Boukadir",
        # Wilaya 03 - Laghouat
        "Laghouat",
        "Aflou",
        "Aïn Madhi",
        # Wilaya 04 - Oum El Bouaghi
        "Oum El Bouaghi",
        "Aïn Mlila",
        "Aïn Beïda",
        # Wilaya 05 - Batna
        "Batna",
        "Barika",
        "Aïn Touta",
        "Arris",
        "N'Gaous",
        # Wilaya 06 - Béjaïa
        "Béjaïa",
        "Akbou",
        "Kherrata",
        "Taklast",
        "Amizour",
        # Wilaya 07 - Biskra
        "Biskra",
        "Tolga",
        "Sidi Okba",
        "Zéribet El Oued",
        # Wilaya 08 - Béchar
        "Béchar",
        "Taghit",
        "Kenadsa",
        # Wilaya 09 - Blida
        "Blida",
        "Boufarik",
        "Larbaa",
        "Bouinan",
        # Wilaya 10 - Bouira
        "Bouira",
        "Sour El Ghozlane",
        "Aïn Bessem",
        # Wilaya 11 - Tamanrasset
        "Tamanrasset",
        "Ablessa",
        # Wilaya 12 - Tébessa
        "Tébessa",
        "Bir El Ater",
        "El Aouinet",
        # Wilaya 13 - Tlemcen
        "Tlemcen",
        "Maghnia",
        "Ghazaouet",
        "Nedroma",
        "Marsa Ben M'Hidi",
        # Wilaya 14 - Tiaret
        "Tiaret",
        "Sougueur",
        "Frenda",
        "Takhmaret",
        # Wilaya 15 - Tizi Ouzou
        "Tizi Ouzou",
        "Draa Ben Khedda",
        "Azeffoun",
        "Boughni",
        "Tigzirt",
        # Wilaya 16 - Alger
        "Alger Centre",
        "Bab El Oued",
        "La Casbah",
        "Sidi M'Hamed",
        "Hussein Dey",
        "El Harrach",
        "Rouiba",
        "Zéralda",
        "Bir Mourad Raïs",
        "Bouzaréah",
        "Chéraga",
        "Draria",
        "Bab Ezzouar",
        "Bordj El Kiffan",
        "Dar El Beïda",
        "Aïn Taya",
        # Wilaya 17 - Djelfa
        "Djelfa",
        "Messaad",
        "Aïn Oussera",
        "Hassi Bahbah",
        # Wilaya 18 - Jijel
        "Jijel",
        "El Milia",
        "Taher",
        "Ziama Mansouriah",
        # Wilaya 19 - Sétif
        "Sétif",
        "El Eulma",
        "Djemila",
        "Aïn Arnat",
        "Bougaa",
        # Wilaya 20 - Saïda
        "Saïda",
        "Aïn El Hadjar",
        # Wilaya 21 - Skikda
        "Skikda",
        "Azzaba",
        "El Harrouch",
        "Collo",
        # Wilaya 22 - Sidi Bel Abbès
        "Sidi Bel Abbès",
        "Aïn El Berd",
        "Marhoum",
        "Tlemnia",
        # Wilaya 23 - Annaba
        "Annaba",
        "El Bouni",
        "Aïn Berda",
        "Sidi Amar",
        # Wilaya 24 - Guelma
        "Guelma",
        "Bouchegouf",
        "Hammam Debagh",
        # Wilaya 25 - Constantine
        "Constantine",
        "El Khroub",
        "Didouche Mourad",
        "Zighoud Youcef",
        "Aïn Abid",
        # Wilaya 26 - Médéa
        "Médéa",
        "Ksar El Boukhari",
        "Berrouaghia",
        "Boughzoul",
        # Wilaya 27 - Mostaganem
        "Mostaganem",
        "Sidi Ali",
        "Aïn Tédeles",
        "Mazagran",
        # Wilaya 28 - M'Sila
        "M'Sila",
        "Bou Saâda",
        "Sidi Aïssa",
        "Aïn El Melh",
        # Wilaya 29 - Mascara
        "Mascara",
        "Tighennif",
        "Bouhanifia",
        "Sig",
        # Wilaya 30 - Ouargla
        "Ouargla",
        "Hassi Messaoud",
        "Aïn El Beïda",
        # Wilaya 31 - Oran
        "Oran",
        "Arzew",
        "Aïn El Turk",
        "Bir El Djir",
        "Mers El Hadjadj",
        "Es Sénia",
        # Wilaya 32 - El Bayadh
        "El Bayadh",
        "Brezina",
        # Wilaya 33 - Illizi
        "Illizi",
        "In Amenas",
        # Wilaya 34 - Bordj Bou Arreridj
        "Bordj Bou Arreridj",
        "Ras El Oued",
        "Aïn Taghrout",
        # Wilaya 35 - Boumerdès
        "Boumerdès",
        "Khemis El Khechna",
        "Bordj Menaïel",
        "Dellys",
        # Wilaya 36 - El Tarf
        "El Tarf",
        "El Kala",
        "Ben M'Hidi",
        # Wilaya 37 - Tindouf
        "Tindouf",
        # Wilaya 38 - Tissemsilt
        "Tissemsilt",
        "Khemisti",
        # Wilaya 39 - El Oued
        "El Oued",
        "Guemar",
        "Hassi Khalifa",
        "Reguiba",
        # Wilaya 40 - Khenchela
        "Khenchela",
        "Babar",
        # Wilaya 41 - Souk Ahras
        "Souk Ahras",
        "Mdaourouch",
        "Sedrata",
        # Wilaya 42 - Tipaza
        "Tipaza",
        "Cherchell",
        "Bou Ismaïl",
        "Koléa",
        # Wilaya 43 - Mila
        "Mila",
        "Ferdjioua",
        "Chelghoum Laïd",
        # Wilaya 44 - Aïn Defla
        "Aïn Defla",
        "Khemis Miliana",
        "El Attaf",
        "Miliana",
        # Wilaya 45 - Naâma
        "Naâma",
        "Mecheria",
        "Aïn Sefra",
        # Wilaya 46 - Aïn Témouchent
        "Aïn Témouchent",
        "Béni Saf",
        "Hammam Bou Hadjar",
        # Wilaya 47 - Ghardaïa
        "Ghardaïa",
        "Guerrara",
        "Metlili",
        "El Atteuf",
        # Wilaya 48 - Relizane
        "Relizane",
        "Mazouna",
        "Oued Rhiou",
        # New wilayas
        "Timimoun",
        "Bordj Badji Mokhtar",
        "Ouled Djellal",
        "Béni Abbès",
        "In Salah",
        "In Guezzam",
        "Touggourt",
        "Djanet",
        "El Meghaier",
        "El Menia",
    )

    street_prefixes: Tuple[str, ...] = (
        "rue",
        "avenue",
        "boulevard",
        "chemin",
    )

    building_number_formats: Tuple[str, ...] = ("%", "%#", "%#", "%##")

    postcode_formats: Tuple[str, ...] = tuple(f"{i:02d}###" for i in range(1, 49))

    street_name_formats: Tuple[str, ...] = (
        "{{street_prefix}} {{last_name}}",
        "{{street_prefix}} {{first_name}} {{last_name}}",
        "{{street_prefix}} de {{last_name}}",
    )

    street_address_formats: Tuple[str, ...] = (
        "{{building_number}} {{street_name}}",
        "{{building_number}}, {{street_name}}",
    )

    address_formats: Tuple[str, ...] = (
        "{{street_address}} {{city}}",
        "{{street_address}} - {{city}}",
        "{{street_address}} {{city}}, {{administrative_unit}}",
        "{{street_address}}, {{city}}, {{administrative_unit}}",
        "{{street_address}} {{city}} - {{administrative_unit}}",
    )

    def street_prefix(self) -> str:
        return self.random_element(self.street_prefixes)

    def city(self) -> str:
        return self.random_element(self.cities)

    def administrative_unit(self) -> str:
        return self.random_element(self.wilayas)

    wilaya = administrative_unit



from .. import Provider as BaseProvider


# Ukrainian job names taken from
# https://uk.wikipedia.org/wiki/%D0%A1%D0%BF%D0%B8%D1%81%D0%BE%D0%BA_%D0%BF%D1%80%D0%BE%D1%84%D0%B5%D1%81%D1%96%D0%B9
# on 22th September 2014
class Provider(BaseProvider):
    jobs = [
        # А
        "Агроном",
        "Адвокат",
        "Актор",
        "Акушер",
        "Антрополог",
        "Архітектор",
        "Археолог",
        "Астронавт",
        "Астроном",
        "Астрофізик",
        # Б
        "Бібліограф",
        "Біолог",
        "Бізнесмен",
        "Ботанік",
        "Будник",
        "Бухгалтер",
        "Бібліотекар",
        # В
        "Ветеринар",
        "Випробувач",
        "Водій",
        "Вчитель",
        "Візажист",
        # Г
        "Географ",
        "Геолог",
        "Геофізик",
        "Гицель",
        "Гінеколог",
        "Гірник",
        "Гірничий інженер",
        "Головний меркшейдер",
        "Графік",
        "Громадський діяч",
        # Ґ
        "Ґрунтознавець",
        # Д
        "Державний службовець",
        "Дерун",
        "Детектив",
        "Дизайнер",
        "Дипломат",
        "Диригент",
        "Доцент",
        "Драматург",
        "Ді-джей",
        "Дантист",
        # Е
        "Економіст",
        "Електрик",
        "Електромонтер",
        "Електромонтажник",
        "Електрослюсар",
        "Електротехнік",
        "Епідеміолог",
        "Етнограф",
        # Є
        "Євнух",
        "Єгер",
        # Ж
        "Журналіст",
        "Живописець",
        # З
        "Золотар",
        "Зоолог",
        # І
        "Інженер",
        "Історик",
        # К
        "Каскадер",
        "Кінорежисер",
        "Клавішник",
        "Клоун",
        "Композитор",
        "Конструктор",
        "Краєзнавець",
        "Кушнір",
        "Кіноактор",
        "Кінокритик",
        "Кінорежисер",
        "Кур'єр",
        "Кухар",
        "Кінолог",
        "Круп'є",
        # Л
        "Льотчик",
        "Лікар",
        "Літературознавець",
        "Локсмайстер",
        # М
        "Математик",
        "Машиніст",
        "Медик",
        "Менеджер",
        "Мистецтвознавець",
        "Мірошник",
        "Мікробіолог",
        "Мінералог",
        "Мовознавець",
        "Модель",
        "Модельєр",
        "Музикант",
        "Музикознавець",
        "Музичний редактор",
        "Маркетолог",
        "М'ясник",
        # Н
        "Намотувальник",
        "Науковець",
        "Няня",
        "Нотаріус",
        # П
        "Палеонтолог",
        "Паралегал",
        "Парфюмер",
        "Патологоанатом",
        "Педагог",
        "Пекар",
        "Перекладач",
        "Петрограф",
        "Письменник",
        "Піаніст",
        "Підприємець",
        "Пілот",
        "Правник",
        "Програміст",
        "Провізор",
        "Прокурор",
        "Промисловець",
        "Професор",
        "Психолог",
        "Публіцист",
        "Продюсер",
        "Паблік рилейшнз",
        # Р
        "Режисер",
        "Різноробочий",
        "Реабілітолог",
        "Редактор",
        "Реставратор",
        "Ріелтор",
        # С
        "Сантехнік",
        "Складальник",
        "Скульптор",
        "Соціолог",
        "Співак",
        "Сценарист",
        "Стропальник",
        "Стоматолог",
        "Слідчий",
        "Стиліст",
        "Секретар",
        # Ф
        "Фармацевт",
        "Фермер",
        "Фізик",
        "Філолог",
        "Фольклорист",
        "Фотограф",
        "Фрілансер",
        "Футболіст",
        "Флорист",
        # Х
        "Хімік",
        "Художник",
        "Хореограф",
        # Ш
        "Шериф",
        "Швачка",
        "Штукатур",
        # Ю
        "Ювелір",
        "Юрист",
    ]



from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    # Sourse: https://www.ganmarteba.ge/
    DAY_NAMES = {
        "0": "კვირა",
        "1": "ორშაბათი",
        "2": "სამშაბათი",
        "3": "ოთხშაბათი",
        "4": "ხუთშაბათი",
        "5": "პარასკევი",
        "6": "შაბათი",
    }

    MONTH_NAMES = {
        "01": "იანვარი",
        "02": "თებერვალი",
        "03": "მარტი",
        "04": "აპრილი",
        "05": "მაისი",
        "06": "ივნისი",
        "07": "ივლისი",
        "08": "აგვისტო",
        "09": "სექტემბერი",
        "10": "ოქტომბერი",
        "11": "ნოემბერი",
        "12": "დეკემბერი",
    }

    def day_of_week(self):
        day = self.date("%w")
        return self.DAY_NAMES[day]

    def month_name(self):
        month = self.month()
        return self.MONTH_NAMES[month]



from typing import Dict, List, Tuple

from .. import BaseProvider
from .isbn import ISBN10, ISBN13, MAX_LENGTH

localized = True


class Provider(BaseProvider):
    """Generates fake ISBNs.

    See https://www.isbn-international.org/content/what-isbn for the
    format of ISBNs.
    See https://www.isbn-international.org/range_file_generation for the
    list of rules pertaining to each prefix/registration group.
    """

    rules: Dict[str, Dict[str, List[Tuple[str, str, int]]]] = {}

    def _body(self) -> List[str]:
        """Generate the information required to create an ISBN-10 or
        ISBN-13.
        """
        ean: str = self.random_element(self.rules.keys())
        reg_group: str = self.random_element(self.rules[ean].keys())

        # Given the chosen ean/group, decide how long the
        #   registrant/publication string may be.
        # We must allocate for the calculated check digit, so
        #   subtract 1
        reg_pub_len: int = MAX_LENGTH - len(ean) - len(reg_group) - 1

        # Generate a registrant/publication combination
        reg_pub: str = self.numerify("#" * reg_pub_len)

        # Use rules to separate the registrant from the publication
        rules = self.rules[ean][reg_group]
        registrant, publication = self._registrant_publication(reg_pub, rules)
        return [ean, reg_group, registrant, publication]

    @staticmethod
    def _registrant_publication(reg_pub: str, rules: List[Tuple[str, str, int]]) -> Tuple[str, str]:
        """Separate the registration from the publication in a given
        string.

        :param reg_pub: A string of digits representing a registration
            and publication.
        :param rules: A list of registrant rules which designate where
            to separate the values in the string.
        :returns: A (registrant, publication) tuple of strings.
        """
        for rule in rules:
            if rule[0] <= reg_pub[:-1] <= rule[1]:
                reg_len = rule[2]
                break
        else:
            raise Exception(f"Registrant/Publication '{reg_pub}' not found in registrant rule list.")
        registrant, publication = reg_pub[:reg_len], reg_pub[reg_len:]
        return registrant, publication

    def isbn13(self, separator: str = "-") -> str:
        """
        :sample:
        """
        ean, group, registrant, publication = self._body()
        isbn = ISBN13(ean, group, registrant, publication)
        return isbn.format(separator)

    def isbn10(self, separator: str = "-") -> str:
        """
        :sample:
        """
        ean, group, registrant, publication = self._body()
        isbn = ISBN10(ean, group, registrant, publication)
        return isbn.format(separator)



import random

from datetime import date, timedelta
from typing import Tuple

from faker.typing import SexLiteral

from .. import Provider as PassportProvider


class Provider(PassportProvider):
    """Implement passport provider for ``en_US`` locale.

    Sources:

    - https://travel.state.gov/content/travel/en/passports/passport-help/next-generation-passport.html
    - https://www.vitalrecordsonline.com/glossary/passport-book-number
    """

    passport_number_formats = (
        # NGP
        "?########",
        # Pre-NGP
        "#########",
    )

    def passport_dates(self, birthday: date = date.today()) -> Tuple[str, str, str]:
        """Generates a formatted date of birth, issue, and expiration dates.
        issue and expiration dates are conditioned to fall within U.S. standards of 5 and 10 year expirations


        The ``birthday`` argument is a datetime.date object representing a date of birth.

        Sources:

        -https://travel.state.gov/content/travel/en/passports/passport-help/faqs.html
        """
        birth_date = f"{birthday:%d %b %Y}"
        today = date.today()
        age = (today - birthday).days // 365
        if age < 16:
            expiry_years = 5
            issue_date = self.generator.date_time_between(today - timedelta(days=expiry_years * 365 - 1), today)
            # Checks if age is less than 5 so issue date is not before birthdate
            if age < 5:
                issue_date = self.generator.date_time_between(birthday, today)
        elif age >= 26:
            expiry_years = 10
            issue_date = self.generator.date_time_between(today - timedelta(days=expiry_years * 365 - 1), today)
        else:
            # In cases between age 16 and 26, the issue date is 5 years ago, but expiry may be in 10 or 5 years
            expiry_years = 5
            issue_date = self.generator.date_time_between(
                today - timedelta(days=expiry_years * 365 - 1), birthday + timedelta(days=16 * 365 - 1)
            )
            # all people over 21 must have been over 16 when they recieved passport or it will be expired otherwise
            if age >= 21:
                issue_date = self.generator.date_time_between(today - timedelta(days=expiry_years * 365 - 1), today)
                expiry_years = 10

        if issue_date.day == 29 and issue_date.month == 2:
            issue_date -= timedelta(days=1)
        expiry_date = issue_date.replace(year=issue_date.year + expiry_years)

        issue_date_format = f"{issue_date:%d %b %Y}"
        expiry_date_format = f"{expiry_date:%d %b %Y}"
        return birth_date, issue_date_format, expiry_date_format

    def passport_gender(self, seed: int = 0) -> SexLiteral:
        """Generates a string representing the gender displayed on a passport

        Sources:

        - https://williamsinstitute.law.ucla.edu/publications/x-gender-markers-passports/
        """
        if seed != 0:
            random.seed(seed)

        genders = ["M", "F", "X"]
        gender: SexLiteral = random.choices(genders, weights=[0.493, 0.493, 0.014], k=1)[0]  # type: ignore
        return gender

    def passport_full(self) -> str:
        """Generates a formatted sting with US Passport information"""
        dob = self.passport_dob()
        birth_date, issue_date, expiry_date = self.passport_dates(dob)
        gender_g = self.passport_gender()
        given_name, surname = self.passport_owner(gender=gender_g)
        number = self.passport_number()

        full_rep = """{first_name}\n{second_name}\n{gender}\n{dob}\n{issue}\n{expire}\n{num}\n"""
        full_rep = full_rep.format(
            first_name=given_name,
            second_name=surname,
            gender=gender_g,
            dob=birth_date,
            issue=issue_date,
            expire=expiry_date,
            num=number,
        )
        return full_rep
